###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::Catalog;

use strict;
use warnings;
use utf8;

sub CLDRVersion { return "1\.7\.1" }

my @Locales;
sub Locales { return @Locales }

my %Aliases;
sub Aliases { return %Aliases }

@Locales = (
    {
      id               => "aa",
      en_language      => "Afar",
      native_language  => "Qafar",
    },
    {
      id               => "aa_DJ",
      en_language      => "Afar",
      en_territory     => "Djibouti",
      native_language  => "Qafar",
      native_territory => "Yabuuti",
    },
    {
      id               => "aa_ER",
      en_language      => "Afar",
      en_territory     => "Eritrea",
      native_language  => "Qafar",
      native_territory => "Eretria",
    },
    {
      id               => "aa_ER_SAAHO",
      en_language      => "Afar",
      en_territory     => "Eritrea",
      en_variant       => "Saho",
      native_language  => "Qafar",
      native_territory => "Eretria",
    },
    {
      id               => "aa_ET",
      en_language      => "Afar",
      en_territory     => "Ethiopia",
      native_language  => "Qafar",
      native_territory => "Otobbia",
    },
    {
      id               => "af",
      en_language      => "Afrikaans",
      native_language  => "Afrikaans",
    },
    {
      id               => "af_NA",
      en_language      => "Afrikaans",
      en_territory     => "Namibia",
      native_language  => "Afrikaans",
      native_territory => "Namibië",
    },
    {
      id               => "af_ZA",
      en_language      => "Afrikaans",
      en_territory     => "South\ Africa",
      native_language  => "Afrikaans",
      native_territory => "Suid\-Afrika",
    },
    {
      id               => "ak",
      en_language      => "Akan",
    },
    {
      id               => "ak_GH",
      en_language      => "Akan",
      en_territory     => "Ghana",
    },
    {
      id               => "am",
      en_language      => "Amharic",
      native_language  => "አማርኛ",
    },
    {
      id               => "am_ET",
      en_language      => "Amharic",
      en_territory     => "Ethiopia",
      native_language  => "አማርኛ",
      native_territory => "ኢትዮጵያ",
    },
    {
      id               => "ar",
      en_language      => "Arabic",
      native_language  => "العربية",
    },
    {
      id               => "ar_AE",
      en_language      => "Arabic",
      en_territory     => "United\ Arab\ Emirates",
      native_language  => "العربية",
      native_territory => "الامارات\ العربية\ المتحدة",
    },
    {
      id               => "ar_BH",
      en_language      => "Arabic",
      en_territory     => "Bahrain",
      native_language  => "العربية",
      native_territory => "البحرين",
    },
    {
      id               => "ar_DZ",
      en_language      => "Arabic",
      en_territory     => "Algeria",
      native_language  => "العربية",
      native_territory => "الجزائر",
    },
    {
      id               => "ar_EG",
      en_language      => "Arabic",
      en_territory     => "Egypt",
      native_language  => "العربية",
      native_territory => "مصر",
    },
    {
      id               => "ar_IQ",
      en_language      => "Arabic",
      en_territory     => "Iraq",
      native_language  => "العربية",
      native_territory => "العراق",
    },
    {
      id               => "ar_JO",
      en_language      => "Arabic",
      en_territory     => "Jordan",
      native_language  => "العربية",
      native_territory => "الأردن",
    },
    {
      id               => "ar_KW",
      en_language      => "Arabic",
      en_territory     => "Kuwait",
      native_language  => "العربية",
      native_territory => "الكويت",
    },
    {
      id               => "ar_LB",
      en_language      => "Arabic",
      en_territory     => "Lebanon",
      native_language  => "العربية",
      native_territory => "لبنان",
    },
    {
      id               => "ar_LY",
      en_language      => "Arabic",
      en_territory     => "Libya",
      native_language  => "العربية",
      native_territory => "ليبيا",
    },
    {
      id               => "ar_MA",
      en_language      => "Arabic",
      en_territory     => "Morocco",
      native_language  => "العربية",
      native_territory => "المغرب",
    },
    {
      id               => "ar_OM",
      en_language      => "Arabic",
      en_territory     => "Oman",
      native_language  => "العربية",
      native_territory => "عمان",
    },
    {
      id               => "ar_QA",
      en_language      => "Arabic",
      en_territory     => "Qatar",
      native_language  => "العربية",
      native_territory => "قطر",
    },
    {
      id               => "ar_SA",
      en_language      => "Arabic",
      en_territory     => "Saudi\ Arabia",
      native_language  => "العربية",
      native_territory => "المملكة\ العربية\ السعودية",
    },
    {
      id               => "ar_SD",
      en_language      => "Arabic",
      en_territory     => "Sudan",
      native_language  => "العربية",
      native_territory => "السودان",
    },
    {
      id               => "ar_SY",
      en_language      => "Arabic",
      en_territory     => "Syria",
      native_language  => "العربية",
      native_territory => "سوريا",
    },
    {
      id               => "ar_TN",
      en_language      => "Arabic",
      en_territory     => "Tunisia",
      native_language  => "العربية",
      native_territory => "تونس",
    },
    {
      id               => "ar_YE",
      en_language      => "Arabic",
      en_territory     => "Yemen",
      native_language  => "العربية",
      native_territory => "اليمن",
    },
    {
      id               => "as",
      en_language      => "Assamese",
      native_language  => "অসমীয়া",
    },
    {
      id               => "as_IN",
      en_language      => "Assamese",
      en_territory     => "India",
      native_language  => "অসমীয়া",
      native_territory => "ভাৰত",
    },
    {
      id               => "az",
      en_language      => "Azerbaijani",
      native_language  => "azərbaycanca",
    },
    {
      id               => "az_AZ",
      en_language      => "Azerbaijani",
      en_territory     => "Azerbaijan",
      native_language  => "azərbaycanca",
      native_territory => "Azərbaycan",
    },
    {
      id               => "az_Cyrl",
      en_language      => "Azerbaijani",
      en_script        => "Cyrillic",
      native_language  => "Азәрбајҹан",
      native_script    => "kiril",
    },
    {
      id               => "az_Cyrl_AZ",
      en_language      => "Azerbaijani",
      en_script        => "Cyrillic",
      en_territory     => "Azerbaijan",
      native_language  => "Азәрбајҹан",
      native_script    => "kiril",
      native_territory => "Азәрбајҹан",
    },
    {
      id               => "az_Latn",
      en_language      => "Azerbaijani",
      en_script        => "Latin",
      native_language  => "azərbaycanca",
      native_script    => "latın",
    },
    {
      id               => "az_Latn_AZ",
      en_language      => "Azerbaijani",
      en_script        => "Latin",
      en_territory     => "Azerbaijan",
      native_language  => "azərbaycanca",
      native_script    => "latın",
      native_territory => "Azərbaycan",
    },
    {
      id               => "be",
      en_language      => "Belarusian",
      native_language  => "беларуская",
    },
    {
      id               => "be_BY",
      en_language      => "Belarusian",
      en_territory     => "Belarus",
      native_language  => "беларуская",
      native_territory => "Беларусь",
    },
    {
      id               => "bg",
      en_language      => "Bulgarian",
      native_language  => "български",
    },
    {
      id               => "bg_BG",
      en_language      => "Bulgarian",
      en_territory     => "Bulgaria",
      native_language  => "български",
      native_territory => "България",
    },
    {
      id               => "bn",
      en_language      => "Bengali",
      native_language  => "বাংলা",
    },
    {
      id               => "bn_BD",
      en_language      => "Bengali",
      en_territory     => "Bangladesh",
      native_language  => "বাংলা",
      native_territory => "বাংলাদেশ",
    },
    {
      id               => "bn_IN",
      en_language      => "Bengali",
      en_territory     => "India",
      native_language  => "বাংলা",
      native_territory => "ভারত",
    },
    {
      id               => "bo",
      en_language      => "Tibetan",
      native_language  => "པོད་སྐད་",
    },
    {
      id               => "bo_CN",
      en_language      => "Tibetan",
      en_territory     => "China",
      native_language  => "པོད་སྐད་",
      native_territory => "རྒྱ་ནག",
    },
    {
      id               => "bo_IN",
      en_language      => "Tibetan",
      en_territory     => "India",
      native_language  => "པོད་སྐད་",
      native_territory => "རྒྱ་གར་",
    },
    {
      id               => "bs",
      en_language      => "Bosnian",
      native_language  => "bosanski",
    },
    {
      id               => "bs_BA",
      en_language      => "Bosnian",
      en_territory     => "Bosnia\ and\ Herzegovina",
      native_language  => "bosanski",
      native_territory => "Bosna\ i\ Hercegovina",
    },
    {
      id               => "byn",
      en_language      => "Blin",
      native_language  => "ብሊን",
    },
    {
      id               => "byn_ER",
      en_language      => "Blin",
      en_territory     => "Eritrea",
      native_language  => "ብሊን",
      native_territory => "ኤርትራ",
    },
    {
      id               => "ca",
      en_language      => "Catalan",
      native_language  => "català",
    },
    {
      id               => "ca_ES",
      en_language      => "Catalan",
      en_territory     => "Spain",
      native_language  => "català",
      native_territory => "Espanya",
    },
    {
      id               => "cch",
      en_language      => "Atsam",
    },
    {
      id               => "cch_NG",
      en_language      => "Atsam",
      en_territory     => "Nigeria",
    },
    {
      id               => "cop",
      en_language      => "Coptic",
    },
    {
      id               => "cs",
      en_language      => "Czech",
      native_language  => "čeština",
    },
    {
      id               => "cs_CZ",
      en_language      => "Czech",
      en_territory     => "Czech\ Republic",
      native_language  => "čeština",
      native_territory => "Česká\ republika",
    },
    {
      id               => "cy",
      en_language      => "Welsh",
      native_language  => "Cymraeg",
    },
    {
      id               => "cy_GB",
      en_language      => "Welsh",
      en_territory     => "United\ Kingdom",
      native_language  => "Cymraeg",
      native_territory => "Prydain\ Fawr",
    },
    {
      id               => "da",
      en_language      => "Danish",
      native_language  => "dansk",
    },
    {
      id               => "da_DK",
      en_language      => "Danish",
      en_territory     => "Denmark",
      native_language  => "dansk",
      native_territory => "Danmark",
    },
    {
      id               => "de",
      en_language      => "German",
      native_language  => "Deutsch",
    },
    {
      id               => "de_AT",
      en_language      => "German",
      en_territory     => "Austria",
      native_language  => "Deutsch",
      native_territory => "Österreich",
    },
    {
      id               => "de_BE",
      en_language      => "German",
      en_territory     => "Belgium",
      native_language  => "Deutsch",
      native_territory => "Belgien",
    },
    {
      id               => "de_CH",
      en_language      => "German",
      en_territory     => "Switzerland",
      native_language  => "Deutsch",
      native_territory => "Schweiz",
    },
    {
      id               => "de_DE",
      en_language      => "German",
      en_territory     => "Germany",
      native_language  => "Deutsch",
      native_territory => "Deutschland",
    },
    {
      id               => "de_LI",
      en_language      => "German",
      en_territory     => "Liechtenstein",
      native_language  => "Deutsch",
      native_territory => "Liechtenstein",
    },
    {
      id               => "de_LU",
      en_language      => "German",
      en_territory     => "Luxembourg",
      native_language  => "Deutsch",
      native_territory => "Luxemburg",
    },
    {
      id               => "dv",
      en_language      => "Divehi",
      native_language  => "ދިވެހިބަސް",
    },
    {
      id               => "dv_MV",
      en_language      => "Divehi",
      en_territory     => "Maldives",
      native_language  => "ދިވެހިބަސް",
      native_territory => "ދިވެހި\ ރާއްޖެ",
    },
    {
      id               => "dz",
      en_language      => "Dzongkha",
      native_language  => "རྫོང་ཁ",
    },
    {
      id               => "dz_BT",
      en_language      => "Dzongkha",
      en_territory     => "Bhutan",
      native_language  => "རྫོང་ཁ",
      native_territory => "འབྲུག",
    },
    {
      id               => "ee",
      en_language      => "Ewe",
    },
    {
      id               => "ee_GH",
      en_language      => "Ewe",
      en_territory     => "Ghana",
    },
    {
      id               => "ee_TG",
      en_language      => "Ewe",
      en_territory     => "Togo",
    },
    {
      id               => "el",
      en_language      => "Greek",
      native_language  => "Ελληνικά",
    },
    {
      id               => "el_CY",
      en_language      => "Greek",
      en_territory     => "Cyprus",
      native_language  => "Ελληνικά",
      native_territory => "Κύπρος",
    },
    {
      id               => "el_GR",
      en_language      => "Greek",
      en_territory     => "Greece",
      native_language  => "Ελληνικά",
      native_territory => "Ελλάδα",
    },
    {
      id               => "el_POLYTON",
      en_language      => "Greek",
      native_language  => "Ἑλληνικά",
    },
    {
      id               => "en",
      en_language      => "English",
      native_language  => "English",
    },
    {
      id               => "en_AS",
      en_language      => "English",
      en_territory     => "American\ Samoa",
      native_language  => "English",
      native_territory => "American\ Samoa",
    },
    {
      id               => "en_AU",
      en_language      => "English",
      en_territory     => "Australia",
      native_language  => "English",
      native_territory => "Australia",
    },
    {
      id               => "en_BE",
      en_language      => "English",
      en_territory     => "Belgium",
      native_language  => "English",
      native_territory => "Belgium",
    },
    {
      id               => "en_BW",
      en_language      => "English",
      en_territory     => "Botswana",
      native_language  => "English",
      native_territory => "Botswana",
    },
    {
      id               => "en_BZ",
      en_language      => "English",
      en_territory     => "Belize",
      native_language  => "English",
      native_territory => "Belize",
    },
    {
      id               => "en_CA",
      en_language      => "English",
      en_territory     => "Canada",
      native_language  => "English",
      native_territory => "Canada",
    },
    {
      id               => "en_Dsrt",
      en_language      => "English",
      en_script        => "Deseret",
      native_language  => "𐐀𐑍𐑊𐐮𐑇",
      native_script    => "𐐔𐐯𐑆𐐲𐑉𐐯𐐻",
    },
    {
      id               => "en_Dsrt_US",
      en_language      => "English",
      en_script        => "Deseret",
      en_territory     => "United\ States",
      native_language  => "𐐀𐑍𐑊𐐮𐑇",
      native_script    => "𐐔𐐯𐑆𐐲𐑉𐐯𐐻",
      native_territory => "𐐏𐐭𐑌𐐴𐐻𐐲𐐼\ 𐐝𐐻𐐩𐐻𐑅",
    },
    {
      id               => "en_GB",
      en_language      => "English",
      en_territory     => "United\ Kingdom",
      native_language  => "English",
      native_territory => "United\ Kingdom",
    },
    {
      id               => "en_GU",
      en_language      => "English",
      en_territory     => "Guam",
      native_language  => "English",
      native_territory => "Guam",
    },
    {
      id               => "en_HK",
      en_language      => "English",
      en_territory     => "Hong\ Kong\ SAR\ China",
      native_language  => "English",
      native_territory => "Hong\ Kong\ SAR\ China",
    },
    {
      id               => "en_IE",
      en_language      => "English",
      en_territory     => "Ireland",
      native_language  => "English",
      native_territory => "Ireland",
    },
    {
      id               => "en_IN",
      en_language      => "English",
      en_territory     => "India",
      native_language  => "English",
      native_territory => "India",
    },
    {
      id               => "en_JM",
      en_language      => "English",
      en_territory     => "Jamaica",
      native_language  => "English",
      native_territory => "Jamaica",
    },
    {
      id               => "en_MH",
      en_language      => "English",
      en_territory     => "Marshall\ Islands",
      native_language  => "English",
      native_territory => "Marshall\ Islands",
    },
    {
      id               => "en_MP",
      en_language      => "English",
      en_territory     => "Northern\ Mariana\ Islands",
      native_language  => "English",
      native_territory => "Northern\ Mariana\ Islands",
    },
    {
      id               => "en_MT",
      en_language      => "English",
      en_territory     => "Malta",
      native_language  => "English",
      native_territory => "Malta",
    },
    {
      id               => "en_NA",
      en_language      => "English",
      en_territory     => "Namibia",
      native_language  => "English",
      native_territory => "Namibia",
    },
    {
      id               => "en_NZ",
      en_language      => "English",
      en_territory     => "New\ Zealand",
      native_language  => "English",
      native_territory => "New\ Zealand",
    },
    {
      id               => "en_PH",
      en_language      => "English",
      en_territory     => "Philippines",
      native_language  => "English",
      native_territory => "Philippines",
    },
    {
      id               => "en_PK",
      en_language      => "English",
      en_territory     => "Pakistan",
      native_language  => "English",
      native_territory => "Pakistan",
    },
    {
      id               => "en_SG",
      en_language      => "English",
      en_territory     => "Singapore",
      native_language  => "English",
      native_territory => "Singapore",
    },
    {
      id               => "en_Shaw",
      en_language      => "English",
      en_script        => "Shavian",
      native_language  => "English",
      native_script    => "Shavian",
    },
    {
      id               => "en_TT",
      en_language      => "English",
      en_territory     => "Trinidad\ and\ Tobago",
      native_language  => "English",
      native_territory => "Trinidad\ and\ Tobago",
    },
    {
      id               => "en_UM",
      en_language      => "English",
      en_territory     => "U\.S\.\ Minor\ Outlying\ Islands",
      native_language  => "English",
      native_territory => "U\.S\.\ Minor\ Outlying\ Islands",
    },
    {
      id               => "en_US",
      en_language      => "English",
      en_territory     => "United\ States",
      native_language  => "English",
      native_territory => "United\ States",
    },
    {
      id               => "en_US_POSIX",
      en_language      => "English",
      en_territory     => "United\ States",
      en_variant       => "Computer",
      native_language  => "English",
      native_territory => "United\ States",
      native_variant   => "Computer",
    },
    {
      id               => "en_VI",
      en_language      => "English",
      en_territory     => "U\.S\.\ Virgin\ Islands",
      native_language  => "English",
      native_territory => "U\.S\.\ Virgin\ Islands",
    },
    {
      id               => "en_ZA",
      en_language      => "English",
      en_territory     => "South\ Africa",
      native_language  => "English",
      native_territory => "South\ Africa",
    },
    {
      id               => "en_ZW",
      en_language      => "English",
      en_territory     => "Zimbabwe",
      native_language  => "English",
      native_territory => "Zimbabwe",
    },
    {
      id               => "eo",
      en_language      => "Esperanto",
      native_language  => "esperanto",
    },
    {
      id               => "es",
      en_language      => "Spanish",
      native_language  => "español",
    },
    {
      id               => "es_AR",
      en_language      => "Spanish",
      en_territory     => "Argentina",
      native_language  => "español",
      native_territory => "Argentina",
    },
    {
      id               => "es_BO",
      en_language      => "Spanish",
      en_territory     => "Bolivia",
      native_language  => "español",
      native_territory => "Bolivia",
    },
    {
      id               => "es_CL",
      en_language      => "Spanish",
      en_territory     => "Chile",
      native_language  => "español",
      native_territory => "Chile",
    },
    {
      id               => "es_CO",
      en_language      => "Spanish",
      en_territory     => "Colombia",
      native_language  => "español",
      native_territory => "Colombia",
    },
    {
      id               => "es_CR",
      en_language      => "Spanish",
      en_territory     => "Costa\ Rica",
      native_language  => "español",
      native_territory => "Costa\ Rica",
    },
    {
      id               => "es_DO",
      en_language      => "Spanish",
      en_territory     => "Dominican\ Republic",
      native_language  => "español",
      native_territory => "República\ Dominicana",
    },
    {
      id               => "es_EC",
      en_language      => "Spanish",
      en_territory     => "Ecuador",
      native_language  => "español",
      native_territory => "Ecuador",
    },
    {
      id               => "es_ES",
      en_language      => "Spanish",
      en_territory     => "Spain",
      native_language  => "español",
      native_territory => "España",
    },
    {
      id               => "es_GT",
      en_language      => "Spanish",
      en_territory     => "Guatemala",
      native_language  => "español",
      native_territory => "Guatemala",
    },
    {
      id               => "es_HN",
      en_language      => "Spanish",
      en_territory     => "Honduras",
      native_language  => "español",
      native_territory => "Honduras",
    },
    {
      id               => "es_MX",
      en_language      => "Spanish",
      en_territory     => "Mexico",
      native_language  => "español",
      native_territory => "México",
    },
    {
      id               => "es_NI",
      en_language      => "Spanish",
      en_territory     => "Nicaragua",
      native_language  => "español",
      native_territory => "Nicaragua",
    },
    {
      id               => "es_PA",
      en_language      => "Spanish",
      en_territory     => "Panama",
      native_language  => "español",
      native_territory => "Panamá",
    },
    {
      id               => "es_PE",
      en_language      => "Spanish",
      en_territory     => "Peru",
      native_language  => "español",
      native_territory => "Perú",
    },
    {
      id               => "es_PR",
      en_language      => "Spanish",
      en_territory     => "Puerto\ Rico",
      native_language  => "español",
      native_territory => "Puerto\ Rico",
    },
    {
      id               => "es_PY",
      en_language      => "Spanish",
      en_territory     => "Paraguay",
      native_language  => "español",
      native_territory => "Paraguay",
    },
    {
      id               => "es_SV",
      en_language      => "Spanish",
      en_territory     => "El\ Salvador",
      native_language  => "español",
      native_territory => "El\ Salvador",
    },
    {
      id               => "es_US",
      en_language      => "Spanish",
      en_territory     => "United\ States",
      native_language  => "español",
      native_territory => "Estados\ Unidos",
    },
    {
      id               => "es_UY",
      en_language      => "Spanish",
      en_territory     => "Uruguay",
      native_language  => "español",
      native_territory => "Uruguay",
    },
    {
      id               => "es_VE",
      en_language      => "Spanish",
      en_territory     => "Venezuela",
      native_language  => "español",
      native_territory => "Venezuela",
    },
    {
      id               => "et",
      en_language      => "Estonian",
      native_language  => "eesti",
    },
    {
      id               => "et_EE",
      en_language      => "Estonian",
      en_territory     => "Estonia",
      native_language  => "eesti",
      native_territory => "Eesti",
    },
    {
      id               => "eu",
      en_language      => "Basque",
      native_language  => "euskara",
    },
    {
      id               => "eu_ES",
      en_language      => "Basque",
      en_territory     => "Spain",
      native_language  => "euskara",
      native_territory => "Espainia",
    },
    {
      id               => "fa",
      en_language      => "Persian",
      native_language  => "فارسی",
    },
    {
      id               => "fa_AF",
      en_language      => "Persian",
      en_territory     => "Afghanistan",
      native_language  => "دری",
      native_territory => "افغانستان",
    },
    {
      id               => "fa_IR",
      en_language      => "Persian",
      en_territory     => "Iran",
      native_language  => "فارسی",
      native_territory => "ایران",
    },
    {
      id               => "fi",
      en_language      => "Finnish",
      native_language  => "suomi",
    },
    {
      id               => "fi_FI",
      en_language      => "Finnish",
      en_territory     => "Finland",
      native_language  => "suomi",
      native_territory => "Suomi",
    },
    {
      id               => "fil",
      en_language      => "Filipino",
      native_language  => "Filipino",
    },
    {
      id               => "fil_PH",
      en_language      => "Filipino",
      en_territory     => "Philippines",
      native_language  => "Filipino",
      native_territory => "Pilipinas",
    },
    {
      id               => "fo",
      en_language      => "Faroese",
      native_language  => "føroyskt",
    },
    {
      id               => "fo_FO",
      en_language      => "Faroese",
      en_territory     => "Faroe\ Islands",
      native_language  => "føroyskt",
      native_territory => "Føroyar",
    },
    {
      id               => "fr",
      en_language      => "French",
      native_language  => "français",
    },
    {
      id               => "fr_BE",
      en_language      => "French",
      en_territory     => "Belgium",
      native_language  => "français",
      native_territory => "Belgique",
    },
    {
      id               => "fr_CA",
      en_language      => "French",
      en_territory     => "Canada",
      native_language  => "français",
      native_territory => "Canada",
    },
    {
      id               => "fr_CH",
      en_language      => "French",
      en_territory     => "Switzerland",
      native_language  => "français",
      native_territory => "Suisse",
    },
    {
      id               => "fr_FR",
      en_language      => "French",
      en_territory     => "France",
      native_language  => "français",
      native_territory => "France",
    },
    {
      id               => "fr_LU",
      en_language      => "French",
      en_territory     => "Luxembourg",
      native_language  => "français",
      native_territory => "Luxembourg",
    },
    {
      id               => "fr_MC",
      en_language      => "French",
      en_territory     => "Monaco",
      native_language  => "français",
      native_territory => "Monaco",
    },
    {
      id               => "fr_SN",
      en_language      => "French",
      en_territory     => "Senegal",
      native_language  => "français",
      native_territory => "Sénégal",
    },
    {
      id               => "fur",
      en_language      => "Friulian",
      native_language  => "furlan",
    },
    {
      id               => "fur_IT",
      en_language      => "Friulian",
      en_territory     => "Italy",
      native_language  => "furlan",
      native_territory => "Italie",
    },
    {
      id               => "ga",
      en_language      => "Irish",
      native_language  => "Gaeilge",
    },
    {
      id               => "ga_IE",
      en_language      => "Irish",
      en_territory     => "Ireland",
      native_language  => "Gaeilge",
      native_territory => "Éire",
    },
    {
      id               => "gaa",
      en_language      => "Ga",
    },
    {
      id               => "gaa_GH",
      en_language      => "Ga",
      en_territory     => "Ghana",
    },
    {
      id               => "gez",
      en_language      => "Geez",
      native_language  => "ግዕዝኛ",
    },
    {
      id               => "gez_ER",
      en_language      => "Geez",
      en_territory     => "Eritrea",
      native_language  => "ግዕዝኛ",
      native_territory => "ኤርትራ",
    },
    {
      id               => "gez_ET",
      en_language      => "Geez",
      en_territory     => "Ethiopia",
      native_language  => "ግዕዝኛ",
      native_territory => "ኢትዮጵያ",
    },
    {
      id               => "gl",
      en_language      => "Galician",
      native_language  => "galego",
    },
    {
      id               => "gl_ES",
      en_language      => "Galician",
      en_territory     => "Spain",
      native_language  => "galego",
      native_territory => "España",
    },
    {
      id               => "gsw",
      en_language      => "Swiss\ German",
      native_language  => "Schwiizertüütsch",
    },
    {
      id               => "gsw_CH",
      en_language      => "Swiss\ German",
      en_territory     => "Switzerland",
      native_language  => "Schwiizertüütsch",
      native_territory => "Schwiiz",
    },
    {
      id               => "gu",
      en_language      => "Gujarati",
      native_language  => "ગુજરાતી",
    },
    {
      id               => "gu_IN",
      en_language      => "Gujarati",
      en_territory     => "India",
      native_language  => "ગુજરાતી",
      native_territory => "ભારત",
    },
    {
      id               => "gv",
      en_language      => "Manx",
      native_language  => "Gaelg",
    },
    {
      id               => "gv_GB",
      en_language      => "Manx",
      en_territory     => "United\ Kingdom",
      native_language  => "Gaelg",
      native_territory => "Rywvaneth\ Unys",
    },
    {
      id               => "ha",
      en_language      => "Hausa",
      native_language  => "Haoussa",
    },
    {
      id               => "ha_Arab",
      en_language      => "Hausa",
      en_script        => "Arabic",
      native_language  => "Haoussa",
    },
    {
      id               => "ha_Arab_NG",
      en_language      => "Hausa",
      en_script        => "Arabic",
      en_territory     => "Nigeria",
      native_language  => "Haoussa",
      native_territory => "Nijeriya",
    },
    {
      id               => "ha_Arab_SD",
      en_language      => "Hausa",
      en_script        => "Arabic",
      en_territory     => "Sudan",
      native_language  => "Haoussa",
    },
    {
      id               => "ha_GH",
      en_language      => "Hausa",
      en_territory     => "Ghana",
      native_language  => "Haoussa",
      native_territory => "Gaana",
    },
    {
      id               => "ha_Latn",
      en_language      => "Hausa",
      en_script        => "Latin",
      native_language  => "Haoussa",
    },
    {
      id               => "ha_Latn_GH",
      en_language      => "Hausa",
      en_script        => "Latin",
      en_territory     => "Ghana",
      native_language  => "Haoussa",
      native_territory => "Gaana",
    },
    {
      id               => "ha_Latn_NE",
      en_language      => "Hausa",
      en_script        => "Latin",
      en_territory     => "Niger",
      native_language  => "Haoussa",
      native_territory => "Nijer",
    },
    {
      id               => "ha_Latn_NG",
      en_language      => "Hausa",
      en_script        => "Latin",
      en_territory     => "Nigeria",
      native_language  => "Haoussa",
      native_territory => "Nijeriya",
    },
    {
      id               => "ha_NE",
      en_language      => "Hausa",
      en_territory     => "Niger",
      native_language  => "Haoussa",
      native_territory => "Nijer",
    },
    {
      id               => "ha_NG",
      en_language      => "Hausa",
      en_territory     => "Nigeria",
      native_language  => "Haoussa",
      native_territory => "Nijeriya",
    },
    {
      id               => "ha_SD",
      en_language      => "Hausa",
      en_territory     => "Sudan",
      native_language  => "Haoussa",
    },
    {
      id               => "haw",
      en_language      => "Hawaiian",
      native_language  => "ʻōlelo\ Hawaiʻi",
    },
    {
      id               => "haw_US",
      en_language      => "Hawaiian",
      en_territory     => "United\ States",
      native_language  => "ʻōlelo\ Hawaiʻi",
      native_territory => "ʻAmelika\ Hui\ Pū\ ʻIa",
    },
    {
      id               => "he",
      en_language      => "Hebrew",
      native_language  => "עברית",
    },
    {
      id               => "he_IL",
      en_language      => "Hebrew",
      en_territory     => "Israel",
      native_language  => "עברית",
      native_territory => "ישראל",
    },
    {
      id               => "hi",
      en_language      => "Hindi",
      native_language  => "हिन्दी",
    },
    {
      id               => "hi_IN",
      en_language      => "Hindi",
      en_territory     => "India",
      native_language  => "हिन्दी",
      native_territory => "भारत",
    },
    {
      id               => "hr",
      en_language      => "Croatian",
      native_language  => "hrvatski",
    },
    {
      id               => "hr_HR",
      en_language      => "Croatian",
      en_territory     => "Croatia",
      native_language  => "hrvatski",
      native_territory => "Hrvatska",
    },
    {
      id               => "hu",
      en_language      => "Hungarian",
      native_language  => "magyar",
    },
    {
      id               => "hu_HU",
      en_language      => "Hungarian",
      en_territory     => "Hungary",
      native_language  => "magyar",
      native_territory => "Magyarország",
    },
    {
      id               => "hy",
      en_language      => "Armenian",
      native_language  => "Հայերէն",
    },
    {
      id               => "hy_AM",
      en_language      => "Armenian",
      en_territory     => "Armenia",
      native_language  => "Հայերէն",
      native_territory => "Հայաստանի\ Հանրապետութիւն",
    },
    {
      id               => "hy_AM_REVISED",
      en_language      => "Armenian",
      en_territory     => "Armenia",
      en_variant       => "Revised\ Orthography",
      native_language  => "Հայերէն",
      native_territory => "Հայաստանի\ Հանրապետութիւն",
    },
    {
      id               => "ia",
      en_language      => "Interlingua",
      native_language  => "interlingua",
    },
    {
      id               => "id",
      en_language      => "Indonesian",
      native_language  => "Bahasa\ Indonesia",
    },
    {
      id               => "id_ID",
      en_language      => "Indonesian",
      en_territory     => "Indonesia",
      native_language  => "Bahasa\ Indonesia",
      native_territory => "Indonesia",
    },
    {
      id               => "ig",
      en_language      => "Igbo",
    },
    {
      id               => "ig_NG",
      en_language      => "Igbo",
      en_territory     => "Nigeria",
    },
    {
      id               => "ii",
      en_language      => "Sichuan\ Yi",
      native_language  => "ꆈꌠꉙ",
    },
    {
      id               => "ii_CN",
      en_language      => "Sichuan\ Yi",
      en_territory     => "China",
      native_language  => "ꆈꌠꉙ",
      native_territory => "ꍏꇩ",
    },
    {
      id               => "is",
      en_language      => "Icelandic",
      native_language  => "íslenska",
    },
    {
      id               => "is_IS",
      en_language      => "Icelandic",
      en_territory     => "Iceland",
      native_language  => "íslenska",
      native_territory => "Ísland",
    },
    {
      id               => "it",
      en_language      => "Italian",
      native_language  => "italiano",
    },
    {
      id               => "it_CH",
      en_language      => "Italian",
      en_territory     => "Switzerland",
      native_language  => "italiano",
      native_territory => "Svizzera",
    },
    {
      id               => "it_IT",
      en_language      => "Italian",
      en_territory     => "Italy",
      native_language  => "italiano",
      native_territory => "Italia",
    },
    {
      id               => "iu",
      en_language      => "Inuktitut",
      native_language  => "ᐃᓄᒃᑎᑐᑦ\ ᑎᑎᕋᐅᓯᖅ",
    },
    {
      id               => "ja",
      en_language      => "Japanese",
      native_language  => "日本語",
    },
    {
      id               => "ja_JP",
      en_language      => "Japanese",
      en_territory     => "Japan",
      native_language  => "日本語",
      native_territory => "日本",
    },
    {
      id               => "ka",
      en_language      => "Georgian",
      native_language  => "ქართული",
    },
    {
      id               => "ka_GE",
      en_language      => "Georgian",
      en_territory     => "Georgia",
      native_language  => "ქართული",
      native_territory => "საქართველო",
    },
    {
      id               => "kaj",
      en_language      => "Jju",
    },
    {
      id               => "kaj_NG",
      en_language      => "Jju",
      en_territory     => "Nigeria",
    },
    {
      id               => "kam",
      en_language      => "Kamba",
    },
    {
      id               => "kam_KE",
      en_language      => "Kamba",
      en_territory     => "Kenya",
    },
    {
      id               => "kcg",
      en_language      => "Tyap",
    },
    {
      id               => "kcg_NG",
      en_language      => "Tyap",
      en_territory     => "Nigeria",
    },
    {
      id               => "kfo",
      en_language      => "Koro",
    },
    {
      id               => "kfo_CI",
      en_language      => "Koro",
      en_territory     => "Côte\ d’Ivoire",
    },
    {
      id               => "kk",
      en_language      => "Kazakh",
      native_language  => "Қазақ",
    },
    {
      id               => "kk_Cyrl",
      en_language      => "Kazakh",
      en_script        => "Cyrillic",
      native_language  => "Қазақ",
    },
    {
      id               => "kk_Cyrl_KZ",
      en_language      => "Kazakh",
      en_script        => "Cyrillic",
      en_territory     => "Kazakhstan",
      native_language  => "Қазақ",
      native_territory => "Қазақстан",
    },
    {
      id               => "kk_KZ",
      en_language      => "Kazakh",
      en_territory     => "Kazakhstan",
      native_language  => "Қазақ",
      native_territory => "Қазақстан",
    },
    {
      id               => "kl",
      en_language      => "Kalaallisut",
      native_language  => "kalaallisut",
    },
    {
      id               => "kl_GL",
      en_language      => "Kalaallisut",
      en_territory     => "Greenland",
      native_language  => "kalaallisut",
      native_territory => "Kalaallit\ Nunaat",
    },
    {
      id               => "km",
      en_language      => "Khmer",
      native_language  => "ភាសាខ្មែរ",
    },
    {
      id               => "km_KH",
      en_language      => "Khmer",
      en_territory     => "Cambodia",
      native_language  => "ភាសាខ្មែរ",
      native_territory => "កម្ពុជា",
    },
    {
      id               => "kn",
      en_language      => "Kannada",
      native_language  => "ಕನ್ನಡ",
    },
    {
      id               => "kn_IN",
      en_language      => "Kannada",
      en_territory     => "India",
      native_language  => "ಕನ್ನಡ",
      native_territory => "ಭಾರತ",
    },
    {
      id               => "ko",
      en_language      => "Korean",
      native_language  => "한국어",
    },
    {
      id               => "ko_KR",
      en_language      => "Korean",
      en_territory     => "South\ Korea",
      native_language  => "한국어",
      native_territory => "대한민국",
    },
    {
      id               => "kok",
      en_language      => "Konkani",
      native_language  => "कोंकणी",
    },
    {
      id               => "kok_IN",
      en_language      => "Konkani",
      en_territory     => "India",
      native_language  => "कोंकणी",
      native_territory => "भारत",
    },
    {
      id               => "kpe",
      en_language      => "Kpelle",
    },
    {
      id               => "kpe_GN",
      en_language      => "Kpelle",
      en_territory     => "Guinea",
    },
    {
      id               => "kpe_LR",
      en_language      => "Kpelle",
      en_territory     => "Liberia",
    },
    {
      id               => "ku",
      en_language      => "Kurdish",
      native_language  => "كوردی",
    },
    {
      id               => "ku_Arab",
      en_language      => "Kurdish",
      en_script        => "Arabic",
      native_language  => "كوردی",
    },
    {
      id               => "ku_Arab_IQ",
      en_language      => "Kurdish",
      en_script        => "Arabic",
      en_territory     => "Iraq",
      native_language  => "كوردی",
    },
    {
      id               => "ku_Arab_IR",
      en_language      => "Kurdish",
      en_script        => "Arabic",
      en_territory     => "Iran",
      native_language  => "كوردی",
    },
    {
      id               => "ku_Arab_SY",
      en_language      => "Kurdish",
      en_script        => "Arabic",
      en_territory     => "Syria",
      native_language  => "كوردی",
    },
    {
      id               => "ku_IQ",
      en_language      => "Kurdish",
      en_territory     => "Iraq",
      native_language  => "كوردی",
    },
    {
      id               => "ku_IR",
      en_language      => "Kurdish",
      en_territory     => "Iran",
      native_language  => "كوردی",
    },
    {
      id               => "ku_Latn",
      en_language      => "Kurdish",
      en_script        => "Latin",
      native_language  => "kurdî",
    },
    {
      id               => "ku_Latn_TR",
      en_language      => "Kurdish",
      en_script        => "Latin",
      en_territory     => "Turkey",
      native_language  => "kurdî",
      native_territory => "Tirkiye",
    },
    {
      id               => "ku_SY",
      en_language      => "Kurdish",
      en_territory     => "Syria",
      native_language  => "كوردی",
    },
    {
      id               => "ku_TR",
      en_language      => "Kurdish",
      en_territory     => "Turkey",
      native_language  => "kurdî",
      native_territory => "Tirkiye",
    },
    {
      id               => "kw",
      en_language      => "Cornish",
      native_language  => "kernewek",
    },
    {
      id               => "kw_GB",
      en_language      => "Cornish",
      en_territory     => "United\ Kingdom",
      native_language  => "kernewek",
      native_territory => "Rywvaneth\ Unys",
    },
    {
      id               => "ky",
      en_language      => "Kirghiz",
      native_language  => "Кыргыз",
    },
    {
      id               => "ky_KG",
      en_language      => "Kirghiz",
      en_territory     => "Kyrgyzstan",
      native_language  => "Кыргыз",
      native_territory => "Кыргызстан",
    },
    {
      id               => "ln",
      en_language      => "Lingala",
      native_language  => "lingála",
    },
    {
      id               => "ln_CD",
      en_language      => "Lingala",
      en_territory     => "Congo\ \-\ Kinshasa",
      native_language  => "lingála",
      native_territory => "Kongó\-Kinsásá",
    },
    {
      id               => "ln_CG",
      en_language      => "Lingala",
      en_territory     => "Congo\ \-\ Brazzaville",
      native_language  => "lingála",
      native_territory => "Kongó\-Brazzaville",
    },
    {
      id               => "lo",
      en_language      => "Lao",
      native_language  => "ລາວ",
    },
    {
      id               => "lo_LA",
      en_language      => "Lao",
      en_territory     => "Laos",
      native_language  => "ລາວ",
      native_territory => "ລາວ",
    },
    {
      id               => "lt",
      en_language      => "Lithuanian",
      native_language  => "lietuvių",
    },
    {
      id               => "lt_LT",
      en_language      => "Lithuanian",
      en_territory     => "Lithuania",
      native_language  => "lietuvių",
      native_territory => "Lietuva",
    },
    {
      id               => "lv",
      en_language      => "Latvian",
      native_language  => "latviešu",
    },
    {
      id               => "lv_LV",
      en_language      => "Latvian",
      en_territory     => "Latvia",
      native_language  => "latviešu",
      native_territory => "Latvija",
    },
    {
      id               => "mk",
      en_language      => "Macedonian",
      native_language  => "македонски",
    },
    {
      id               => "mk_MK",
      en_language      => "Macedonian",
      en_territory     => "Macedonia",
      native_language  => "македонски",
      native_territory => "Македонија",
    },
    {
      id               => "ml",
      en_language      => "Malayalam",
      native_language  => "മലയാളം",
    },
    {
      id               => "ml_IN",
      en_language      => "Malayalam",
      en_territory     => "India",
      native_language  => "മലയാളം",
      native_territory => "ഇന്ത്യ",
    },
    {
      id               => "mn",
      en_language      => "Mongolian",
      native_language  => "монгол",
    },
    {
      id               => "mn_CN",
      en_language      => "Mongolian",
      en_territory     => "China",
      native_language  => "монгол",
    },
    {
      id               => "mn_Cyrl",
      en_language      => "Mongolian",
      en_script        => "Cyrillic",
      native_language  => "монгол",
    },
    {
      id               => "mn_Cyrl_MN",
      en_language      => "Mongolian",
      en_script        => "Cyrillic",
      en_territory     => "Mongolia",
      native_language  => "монгол",
      native_territory => "Монгол\ улс",
    },
    {
      id               => "mn_MN",
      en_language      => "Mongolian",
      en_territory     => "Mongolia",
      native_language  => "монгол",
      native_territory => "Монгол\ улс",
    },
    {
      id               => "mn_Mong",
      en_language      => "Mongolian",
      en_script        => "Mongolian",
      native_language  => "монгол",
    },
    {
      id               => "mn_Mong_CN",
      en_language      => "Mongolian",
      en_script        => "Mongolian",
      en_territory     => "China",
      native_language  => "монгол",
    },
    {
      id               => "mo",
      en_language      => "Moldavian",
      native_language  => "moldovenească",
    },
    {
      id               => "mr",
      en_language      => "Marathi",
      native_language  => "मराठी",
    },
    {
      id               => "mr_IN",
      en_language      => "Marathi",
      en_territory     => "India",
      native_language  => "मराठी",
      native_territory => "भारत",
    },
    {
      id               => "ms",
      en_language      => "Malay",
      native_language  => "Bahasa\ Melayu",
    },
    {
      id               => "ms_BN",
      en_language      => "Malay",
      en_territory     => "Brunei",
      native_language  => "Bahasa\ Melayu",
      native_territory => "Brunei",
    },
    {
      id               => "ms_MY",
      en_language      => "Malay",
      en_territory     => "Malaysia",
      native_language  => "Bahasa\ Melayu",
      native_territory => "Malaysia",
    },
    {
      id               => "mt",
      en_language      => "Maltese",
      native_language  => "Malti",
    },
    {
      id               => "mt_MT",
      en_language      => "Maltese",
      en_territory     => "Malta",
      native_language  => "Malti",
      native_territory => "Malta",
    },
    {
      id               => "my",
      en_language      => "Burmese",
      native_language  => "ဗမာ",
    },
    {
      id               => "my_MM",
      en_language      => "Burmese",
      en_territory     => "Myanmar\ \[Burma\]",
      native_language  => "ဗမာ",
      native_territory => "မြန်မာ",
    },
    {
      id               => "nb",
      en_language      => "Norwegian\ Bokmål",
      native_language  => "norsk\ bokmål",
    },
    {
      id               => "nb_NO",
      en_language      => "Norwegian\ Bokmål",
      en_territory     => "Norway",
      native_language  => "norsk\ bokmål",
      native_territory => "Norge",
    },
    {
      id               => "nds",
      en_language      => "Low\ German",
      native_language  => "Plattdüütsch",
    },
    {
      id               => "nds_DE",
      en_language      => "Low\ German",
      en_territory     => "Germany",
      native_language  => "Plattdüütsch",
      native_territory => "Düütschland",
    },
    {
      id               => "ne",
      en_language      => "Nepali",
      native_language  => "नेपाली",
    },
    {
      id               => "ne_IN",
      en_language      => "Nepali",
      en_territory     => "India",
      native_language  => "नेपाली",
      native_territory => "भारत",
    },
    {
      id               => "ne_NP",
      en_language      => "Nepali",
      en_territory     => "Nepal",
      native_language  => "नेपाली",
      native_territory => "नेपाल",
    },
    {
      id               => "nl",
      en_language      => "Dutch",
      native_language  => "Nederlands",
    },
    {
      id               => "nl_BE",
      en_language      => "Dutch",
      en_territory     => "Belgium",
      native_language  => "Nederlands",
      native_territory => "België",
    },
    {
      id               => "nl_NL",
      en_language      => "Dutch",
      en_territory     => "Netherlands",
      native_language  => "Nederlands",
      native_territory => "Nederland",
    },
    {
      id               => "nn",
      en_language      => "Norwegian\ Nynorsk",
      native_language  => "nynorsk",
    },
    {
      id               => "nn_NO",
      en_language      => "Norwegian\ Nynorsk",
      en_territory     => "Norway",
      native_language  => "nynorsk",
      native_territory => "Noreg",
    },
    {
      id               => "no",
      en_language      => "Norwegian",
      native_language  => "norsk",
    },
    {
      id               => "nr",
      en_language      => "South\ Ndebele",
      native_language  => "isiNdebele",
    },
    {
      id               => "nr_ZA",
      en_language      => "South\ Ndebele",
      en_territory     => "South\ Africa",
      native_language  => "isiNdebele",
    },
    {
      id               => "nso",
      en_language      => "Northern\ Sotho",
      native_language  => "Sesotho\ sa\ Leboa",
    },
    {
      id               => "nso_ZA",
      en_language      => "Northern\ Sotho",
      en_territory     => "South\ Africa",
      native_language  => "Sesotho\ sa\ Leboa",
    },
    {
      id               => "ny",
      en_language      => "Nyanja",
    },
    {
      id               => "ny_MW",
      en_language      => "Nyanja",
      en_territory     => "Malawi",
    },
    {
      id               => "oc",
      en_language      => "Occitan",
      native_language  => "occitan",
    },
    {
      id               => "oc_FR",
      en_language      => "Occitan",
      en_territory     => "France",
      native_language  => "occitan",
      native_territory => "França",
    },
    {
      id               => "om",
      en_language      => "Oromo",
      native_language  => "Oromoo",
    },
    {
      id               => "om_ET",
      en_language      => "Oromo",
      en_territory     => "Ethiopia",
      native_language  => "Oromoo",
      native_territory => "Itoophiyaa",
    },
    {
      id               => "om_KE",
      en_language      => "Oromo",
      en_territory     => "Kenya",
      native_language  => "Oromoo",
      native_territory => "Keeniyaa",
    },
    {
      id               => "or",
      en_language      => "Oriya",
      native_language  => "ଓଡ଼ିଆ",
    },
    {
      id               => "or_IN",
      en_language      => "Oriya",
      en_territory     => "India",
      native_language  => "ଓଡ଼ିଆ",
      native_territory => "ଭାରତ",
    },
    {
      id               => "pa",
      en_language      => "Punjabi",
      native_language  => "ਪੰਜਾਬੀ",
    },
    {
      id               => "pa_Arab",
      en_language      => "Punjabi",
      en_script        => "Arabic",
      native_language  => "پنجاب",
      native_script    => "العربية",
    },
    {
      id               => "pa_Arab_PK",
      en_language      => "Punjabi",
      en_script        => "Arabic",
      en_territory     => "Pakistan",
      native_language  => "پنجاب",
      native_script    => "العربية",
      native_territory => "پکستان",
    },
    {
      id               => "pa_Guru",
      en_language      => "Punjabi",
      en_script        => "Gurmukhi",
      native_language  => "ਪੰਜਾਬੀ",
      native_script    => "ਗੁਰਮੁਖੀ",
    },
    {
      id               => "pa_Guru_IN",
      en_language      => "Punjabi",
      en_script        => "Gurmukhi",
      en_territory     => "India",
      native_language  => "ਪੰਜਾਬੀ",
      native_script    => "ਗੁਰਮੁਖੀ",
      native_territory => "ਭਾਰਤ",
    },
    {
      id               => "pa_IN",
      en_language      => "Punjabi",
      en_territory     => "India",
      native_language  => "ਪੰਜਾਬੀ",
      native_territory => "ਭਾਰਤ",
    },
    {
      id               => "pa_PK",
      en_language      => "Punjabi",
      en_territory     => "Pakistan",
      native_language  => "پنجاب",
      native_territory => "پکستان",
    },
    {
      id               => "pl",
      en_language      => "Polish",
      native_language  => "polski",
    },
    {
      id               => "pl_PL",
      en_language      => "Polish",
      en_territory     => "Poland",
      native_language  => "polski",
      native_territory => "Polska",
    },
    {
      id               => "ps",
      en_language      => "Pashto",
      native_language  => "پښتو",
    },
    {
      id               => "ps_AF",
      en_language      => "Pashto",
      en_territory     => "Afghanistan",
      native_language  => "پښتو",
      native_territory => "افغانستان",
    },
    {
      id               => "pt",
      en_language      => "Portuguese",
      native_language  => "português",
    },
    {
      id               => "pt_BR",
      en_language      => "Portuguese",
      en_territory     => "Brazil",
      native_language  => "português",
      native_territory => "Brasil",
    },
    {
      id               => "pt_PT",
      en_language      => "Portuguese",
      en_territory     => "Portugal",
      native_language  => "português",
      native_territory => "Portugal",
    },
    {
      id               => "ro",
      en_language      => "Romanian",
      native_language  => "română",
    },
    {
      id               => "ro_MD",
      en_language      => "Romanian",
      en_territory     => "Moldova",
      native_language  => "română",
      native_territory => "Republica\ Moldova",
    },
    {
      id               => "ro_RO",
      en_language      => "Romanian",
      en_territory     => "Romania",
      native_language  => "română",
      native_territory => "România",
    },
    {
      id               => "root",
      en_language      => "Root",
    },
    {
      id               => "ru",
      en_language      => "Russian",
      native_language  => "русский",
    },
    {
      id               => "ru_RU",
      en_language      => "Russian",
      en_territory     => "Russia",
      native_language  => "русский",
      native_territory => "Россия",
    },
    {
      id               => "ru_UA",
      en_language      => "Russian",
      en_territory     => "Ukraine",
      native_language  => "русский",
      native_territory => "Украина",
    },
    {
      id               => "rw",
      en_language      => "Kinyarwanda",
    },
    {
      id               => "rw_RW",
      en_language      => "Kinyarwanda",
      en_territory     => "Rwanda",
    },
    {
      id               => "sa",
      en_language      => "Sanskrit",
      native_language  => "संस्कृत\ भाषा",
    },
    {
      id               => "sa_IN",
      en_language      => "Sanskrit",
      en_territory     => "India",
      native_language  => "संस्कृत\ भाषा",
      native_territory => "भारतम्",
    },
    {
      id               => "se",
      en_language      => "Northern\ Sami",
      native_language  => "davvisámegiella",
    },
    {
      id               => "se_FI",
      en_language      => "Northern\ Sami",
      en_territory     => "Finland",
      native_language  => "se",
      native_territory => "FI",
    },
    {
      id               => "se_NO",
      en_language      => "Northern\ Sami",
      en_territory     => "Norway",
      native_language  => "davvisámegiella",
      native_territory => "Norga",
    },
    {
      id               => "sh",
      en_language      => "Serbo\-Croatian",
      native_language  => "Srpskohrvatski",
    },
    {
      id               => "sh_BA",
      en_language      => "Serbo\-Croatian",
      en_territory     => "Bosnia\ and\ Herzegovina",
      native_language  => "Srpskohrvatski",
      native_territory => "Bosna\ i\ Hercegovina",
    },
    {
      id               => "sh_CS",
      en_language      => "Serbo\-Croatian",
      en_territory     => "Serbia\ and\ Montenegro",
      native_language  => "Srpskohrvatski",
      native_territory => "Srbija\ i\ Crna\ Gora",
    },
    {
      id               => "sh_YU",
      en_language      => "Serbo\-Croatian",
      native_language  => "Srpskohrvatski",
    },
    {
      id               => "si",
      en_language      => "Sinhala",
      native_language  => "සිංහල",
    },
    {
      id               => "si_LK",
      en_language      => "Sinhala",
      en_territory     => "Sri\ Lanka",
      native_language  => "සිංහල",
      native_territory => "ශ්‍රී\ ලංකාව",
    },
    {
      id               => "sid",
      en_language      => "Sidamo",
      native_language  => "Sidaamu\ Afo",
    },
    {
      id               => "sid_ET",
      en_language      => "Sidamo",
      en_territory     => "Ethiopia",
      native_language  => "Sidaamu\ Afo",
      native_territory => "Itiyoophiya",
    },
    {
      id               => "sk",
      en_language      => "Slovak",
      native_language  => "slovenčina",
    },
    {
      id               => "sk_SK",
      en_language      => "Slovak",
      en_territory     => "Slovakia",
      native_language  => "slovenčina",
      native_territory => "Slovenská\ republika",
    },
    {
      id               => "sl",
      en_language      => "Slovenian",
      native_language  => "slovenščina",
    },
    {
      id               => "sl_SI",
      en_language      => "Slovenian",
      en_territory     => "Slovenia",
      native_language  => "slovenščina",
      native_territory => "Slovenija",
    },
    {
      id               => "so",
      en_language      => "Somali",
      native_language  => "Soomaali",
    },
    {
      id               => "so_DJ",
      en_language      => "Somali",
      en_territory     => "Djibouti",
      native_language  => "Soomaali",
      native_territory => "Jabuuti",
    },
    {
      id               => "so_ET",
      en_language      => "Somali",
      en_territory     => "Ethiopia",
      native_language  => "Soomaali",
      native_territory => "Itoobiya",
    },
    {
      id               => "so_KE",
      en_language      => "Somali",
      en_territory     => "Kenya",
      native_language  => "Soomaali",
      native_territory => "Kiiniya",
    },
    {
      id               => "so_SO",
      en_language      => "Somali",
      en_territory     => "Somalia",
      native_language  => "Soomaali",
      native_territory => "Soomaaliya",
    },
    {
      id               => "sq",
      en_language      => "Albanian",
      native_language  => "shqipe",
    },
    {
      id               => "sq_AL",
      en_language      => "Albanian",
      en_territory     => "Albania",
      native_language  => "shqipe",
      native_territory => "Shqipëria",
    },
    {
      id               => "sr",
      en_language      => "Serbian",
      native_language  => "Српски",
    },
    {
      id               => "sr_BA",
      en_language      => "Serbian",
      en_territory     => "Bosnia\ and\ Herzegovina",
      native_language  => "српски",
      native_territory => "Босна\ и\ Херцеговина",
    },
    {
      id               => "sr_CS",
      en_language      => "Serbian",
      en_territory     => "Serbia\ and\ Montenegro",
      native_language  => "Српски",
      native_territory => "Србија\ и\ Црна\ Гора",
    },
    {
      id               => "sr_Cyrl",
      en_language      => "Serbian",
      en_script        => "Cyrillic",
      native_language  => "Српски",
      native_script    => "Ћирилица",
    },
    {
      id               => "sr_Cyrl_BA",
      en_language      => "Serbian",
      en_script        => "Cyrillic",
      en_territory     => "Bosnia\ and\ Herzegovina",
      native_language  => "српски",
      native_script    => "Ћирилица",
      native_territory => "Босна\ и\ Херцеговина",
    },
    {
      id               => "sr_Cyrl_CS",
      en_language      => "Serbian",
      en_script        => "Cyrillic",
      en_territory     => "Serbia\ and\ Montenegro",
      native_language  => "Српски",
      native_script    => "Ћирилица",
      native_territory => "Србија\ и\ Црна\ Гора",
    },
    {
      id               => "sr_Cyrl_ME",
      en_language      => "Serbian",
      en_script        => "Cyrillic",
      en_territory     => "Montenegro",
      native_language  => "Српски",
      native_script    => "Ћирилица",
      native_territory => "Црна\ Гора",
    },
    {
      id               => "sr_Cyrl_RS",
      en_language      => "Serbian",
      en_script        => "Cyrillic",
      en_territory     => "Serbia",
      native_language  => "Српски",
      native_script    => "Ћирилица",
      native_territory => "Србија",
    },
    {
      id               => "sr_Cyrl_YU",
      en_language      => "Serbian",
      en_script        => "Cyrillic",
      native_language  => "Српски",
      native_script    => "Ћирилица",
    },
    {
      id               => "sr_Latn",
      en_language      => "Serbian",
      en_script        => "Latin",
      native_language  => "Srpski",
      native_script    => "Latinica",
    },
    {
      id               => "sr_Latn_BA",
      en_language      => "Serbian",
      en_script        => "Latin",
      en_territory     => "Bosnia\ and\ Herzegovina",
      native_language  => "Srpski",
      native_script    => "Latinica",
      native_territory => "Bosna\ i\ Hercegovina",
    },
    {
      id               => "sr_Latn_CS",
      en_language      => "Serbian",
      en_script        => "Latin",
      en_territory     => "Serbia\ and\ Montenegro",
      native_language  => "Srpski",
      native_script    => "Latinica",
      native_territory => "Srbija\ i\ Crna\ Gora",
    },
    {
      id               => "sr_Latn_ME",
      en_language      => "Serbian",
      en_script        => "Latin",
      en_territory     => "Montenegro",
      native_language  => "Srpski",
      native_script    => "Latinica",
      native_territory => "Crna\ Gora",
    },
    {
      id               => "sr_Latn_RS",
      en_language      => "Serbian",
      en_script        => "Latin",
      en_territory     => "Serbia",
      native_language  => "Srpski",
      native_script    => "Latinica",
      native_territory => "Srbija",
    },
    {
      id               => "sr_Latn_YU",
      en_language      => "Serbian",
      en_script        => "Latin",
      native_language  => "Srpski",
      native_script    => "Latinica",
    },
    {
      id               => "sr_ME",
      en_language      => "Serbian",
      en_territory     => "Montenegro",
      native_language  => "Srpski",
      native_territory => "Crna\ Gora",
    },
    {
      id               => "sr_RS",
      en_language      => "Serbian",
      en_territory     => "Serbia",
      native_language  => "Српски",
      native_territory => "Србија",
    },
    {
      id               => "sr_YU",
      en_language      => "Serbian",
      native_language  => "Српски",
    },
    {
      id               => "ss",
      en_language      => "Swati",
      native_language  => "Siswati",
    },
    {
      id               => "ss_SZ",
      en_language      => "Swati",
      en_territory     => "Swaziland",
      native_language  => "Siswati",
    },
    {
      id               => "ss_ZA",
      en_language      => "Swati",
      en_territory     => "South\ Africa",
      native_language  => "Siswati",
    },
    {
      id               => "st",
      en_language      => "Southern\ Sotho",
      native_language  => "Sesotho",
    },
    {
      id               => "st_LS",
      en_language      => "Southern\ Sotho",
      en_territory     => "Lesotho",
      native_language  => "Sesotho",
    },
    {
      id               => "st_ZA",
      en_language      => "Southern\ Sotho",
      en_territory     => "South\ Africa",
      native_language  => "Sesotho",
    },
    {
      id               => "sv",
      en_language      => "Swedish",
      native_language  => "svenska",
    },
    {
      id               => "sv_FI",
      en_language      => "Swedish",
      en_territory     => "Finland",
      native_language  => "svenska",
      native_territory => "Finland",
    },
    {
      id               => "sv_SE",
      en_language      => "Swedish",
      en_territory     => "Sweden",
      native_language  => "svenska",
      native_territory => "Sverige",
    },
    {
      id               => "sw",
      en_language      => "Swahili",
      native_language  => "Kiswahili",
    },
    {
      id               => "sw_KE",
      en_language      => "Swahili",
      en_territory     => "Kenya",
      native_language  => "Kiswahili",
      native_territory => "Kenya",
    },
    {
      id               => "sw_TZ",
      en_language      => "Swahili",
      en_territory     => "Tanzania",
      native_language  => "Kiswahili",
      native_territory => "Tanzania",
    },
    {
      id               => "syr",
      en_language      => "Syriac",
      native_language  => "ܣܘܪܝܝܐ",
    },
    {
      id               => "syr_SY",
      en_language      => "Syriac",
      en_territory     => "Syria",
      native_language  => "ܣܘܪܝܝܐ",
      native_territory => "ܣܘܪܝܝܐ",
    },
    {
      id               => "ta",
      en_language      => "Tamil",
      native_language  => "தமிழ்",
    },
    {
      id               => "ta_IN",
      en_language      => "Tamil",
      en_territory     => "India",
      native_language  => "தமிழ்",
      native_territory => "இந்தியா",
    },
    {
      id               => "te",
      en_language      => "Telugu",
      native_language  => "తెలుగు",
    },
    {
      id               => "te_IN",
      en_language      => "Telugu",
      en_territory     => "India",
      native_language  => "తెలుగు",
      native_territory => "భారత\ దేశం",
    },
    {
      id               => "tg",
      en_language      => "Tajik",
    },
    {
      id               => "tg_Cyrl",
      en_language      => "Tajik",
      en_script        => "Cyrillic",
    },
    {
      id               => "tg_Cyrl_TJ",
      en_language      => "Tajik",
      en_script        => "Cyrillic",
      en_territory     => "Tajikistan",
    },
    {
      id               => "tg_TJ",
      en_language      => "Tajik",
      en_territory     => "Tajikistan",
    },
    {
      id               => "th",
      en_language      => "Thai",
      native_language  => "ไทย",
    },
    {
      id               => "th_TH",
      en_language      => "Thai",
      en_territory     => "Thailand",
      native_language  => "ไทย",
      native_territory => "ไทย",
    },
    {
      id               => "ti",
      en_language      => "Tigrinya",
      native_language  => "ትግርኛ",
    },
    {
      id               => "ti_ER",
      en_language      => "Tigrinya",
      en_territory     => "Eritrea",
      native_language  => "ትግርኛ",
      native_territory => "ኤርትራ",
    },
    {
      id               => "ti_ET",
      en_language      => "Tigrinya",
      en_territory     => "Ethiopia",
      native_language  => "ትግርኛ",
      native_territory => "ኢትዮጵያ",
    },
    {
      id               => "tig",
      en_language      => "Tigre",
      native_language  => "ትግረ",
    },
    {
      id               => "tig_ER",
      en_language      => "Tigre",
      en_territory     => "Eritrea",
      native_language  => "ትግረ",
      native_territory => "ኤርትራ",
    },
    {
      id               => "tl",
      en_language      => "Tagalog",
      native_language  => "Tagalog",
    },
    {
      id               => "tn",
      en_language      => "Tswana",
      native_language  => "Setswana",
    },
    {
      id               => "tn_ZA",
      en_language      => "Tswana",
      en_territory     => "South\ Africa",
      native_language  => "Setswana",
    },
    {
      id               => "to",
      en_language      => "Tonga",
      native_language  => "lea\ fakatonga",
    },
    {
      id               => "to_TO",
      en_language      => "Tonga",
      en_territory     => "Tonga",
      native_language  => "lea\ fakatonga",
      native_territory => "Tonga",
    },
    {
      id               => "tr",
      en_language      => "Turkish",
      native_language  => "Türkçe",
    },
    {
      id               => "tr_TR",
      en_language      => "Turkish",
      en_territory     => "Turkey",
      native_language  => "Türkçe",
      native_territory => "Türkiye",
    },
    {
      id               => "trv",
      en_language      => "Taroko",
    },
    {
      id               => "trv_TW",
      en_language      => "Taroko",
      en_territory     => "Taiwan",
    },
    {
      id               => "ts",
      en_language      => "Tsonga",
      native_language  => "Xitsonga",
    },
    {
      id               => "ts_ZA",
      en_language      => "Tsonga",
      en_territory     => "South\ Africa",
      native_language  => "Xitsonga",
    },
    {
      id               => "tt",
      en_language      => "Tatar",
      native_language  => "Татар",
    },
    {
      id               => "tt_RU",
      en_language      => "Tatar",
      en_territory     => "Russia",
      native_language  => "Татар",
      native_territory => "Россия",
    },
    {
      id               => "ug",
      en_language      => "Uighur",
    },
    {
      id               => "ug_Arab",
      en_language      => "Uighur",
      en_script        => "Arabic",
    },
    {
      id               => "ug_Arab_CN",
      en_language      => "Uighur",
      en_script        => "Arabic",
      en_territory     => "China",
    },
    {
      id               => "ug_CN",
      en_language      => "Uighur",
      en_territory     => "China",
    },
    {
      id               => "uk",
      en_language      => "Ukrainian",
      native_language  => "українська",
    },
    {
      id               => "uk_UA",
      en_language      => "Ukrainian",
      en_territory     => "Ukraine",
      native_language  => "українська",
      native_territory => "Україна",
    },
    {
      id               => "ur",
      en_language      => "Urdu",
      native_language  => "اردو",
    },
    {
      id               => "ur_IN",
      en_language      => "Urdu",
      en_territory     => "India",
      native_language  => "اردو",
      native_territory => "بھارت",
    },
    {
      id               => "ur_PK",
      en_language      => "Urdu",
      en_territory     => "Pakistan",
      native_language  => "اردو",
      native_territory => "پاکستان",
    },
    {
      id               => "uz",
      en_language      => "Uzbek",
      native_language  => "Ўзбек",
    },
    {
      id               => "uz_AF",
      en_language      => "Uzbek",
      en_territory     => "Afghanistan",
      native_language  => "اۉزبېک",
      native_territory => "افغانستان",
    },
    {
      id               => "uz_Arab",
      en_language      => "Uzbek",
      en_script        => "Arabic",
      native_language  => "اۉزبېک",
      native_script    => "Араб",
    },
    {
      id               => "uz_Arab_AF",
      en_language      => "Uzbek",
      en_script        => "Arabic",
      en_territory     => "Afghanistan",
      native_language  => "اۉزبېک",
      native_script    => "Араб",
      native_territory => "افغانستان",
    },
    {
      id               => "uz_Cyrl",
      en_language      => "Uzbek",
      en_script        => "Cyrillic",
      native_language  => "Ўзбек",
      native_script    => "Кирил",
    },
    {
      id               => "uz_Cyrl_UZ",
      en_language      => "Uzbek",
      en_script        => "Cyrillic",
      en_territory     => "Uzbekistan",
      native_language  => "Ўзбек",
      native_script    => "Кирил",
      native_territory => "Ўзбекистон",
    },
    {
      id               => "uz_Latn",
      en_language      => "Uzbek",
      en_script        => "Latin",
      native_language  => "o\'zbekcha",
      native_script    => "Lotin",
    },
    {
      id               => "uz_Latn_UZ",
      en_language      => "Uzbek",
      en_script        => "Latin",
      en_territory     => "Uzbekistan",
      native_language  => "o\'zbekcha",
      native_script    => "Lotin",
      native_territory => "Oʿzbekiston",
    },
    {
      id               => "uz_UZ",
      en_language      => "Uzbek",
      en_territory     => "Uzbekistan",
      native_language  => "Ўзбек",
      native_territory => "Ўзбекистон",
    },
    {
      id               => "ve",
      en_language      => "Venda",
      native_language  => "Tshivenḓa",
    },
    {
      id               => "ve_ZA",
      en_language      => "Venda",
      en_territory     => "South\ Africa",
      native_language  => "Tshivenḓa",
    },
    {
      id               => "vi",
      en_language      => "Vietnamese",
      native_language  => "Tiếng\ Việt",
    },
    {
      id               => "vi_VN",
      en_language      => "Vietnamese",
      en_territory     => "Vietnam",
      native_language  => "Tiếng\ Việt",
      native_territory => "Việt\ Nam",
    },
    {
      id               => "wal",
      en_language      => "Walamo",
      native_language  => "ወላይታቱ",
    },
    {
      id               => "wal_ET",
      en_language      => "Walamo",
      en_territory     => "Ethiopia",
      native_language  => "ወላይታቱ",
      native_territory => "ኢትዮጵያ",
    },
    {
      id               => "wo",
      en_language      => "Wolof",
    },
    {
      id               => "wo_Latn",
      en_language      => "Wolof",
      en_script        => "Latin",
    },
    {
      id               => "wo_Latn_SN",
      en_language      => "Wolof",
      en_script        => "Latin",
      en_territory     => "Senegal",
    },
    {
      id               => "wo_SN",
      en_language      => "Wolof",
      en_territory     => "Senegal",
    },
    {
      id               => "xh",
      en_language      => "Xhosa",
      native_language  => "isiXhosa",
    },
    {
      id               => "xh_ZA",
      en_language      => "Xhosa",
      en_territory     => "South\ Africa",
      native_language  => "isiXhosa",
    },
    {
      id               => "yo",
      en_language      => "Yoruba",
      native_language  => "Yorùbá",
    },
    {
      id               => "yo_NG",
      en_language      => "Yoruba",
      en_territory     => "Nigeria",
      native_language  => "Yorùbá",
      native_territory => "NG",
    },
    {
      id               => "zh",
      en_language      => "Chinese",
      native_language  => "中文",
    },
    {
      id               => "zh_CN",
      en_language      => "Chinese",
      en_territory     => "China",
      native_language  => "中文",
      native_territory => "中国",
    },
    {
      id               => "zh_HK",
      en_language      => "Chinese",
      en_territory     => "Hong\ Kong\ SAR\ China",
      native_language  => "中文",
      native_territory => "中華人民共和國香港特別行政區",
    },
    {
      id               => "zh_Hans",
      en_language      => "Chinese",
      en_script        => "Simplified\ Han",
      native_language  => "中文",
      native_script    => "简体中文",
    },
    {
      id               => "zh_Hans_CN",
      en_language      => "Chinese",
      en_script        => "Simplified\ Han",
      en_territory     => "China",
      native_language  => "中文",
      native_script    => "简体中文",
      native_territory => "中国",
    },
    {
      id               => "zh_Hans_HK",
      en_language      => "Chinese",
      en_script        => "Simplified\ Han",
      en_territory     => "Hong\ Kong\ SAR\ China",
      native_language  => "中文",
      native_script    => "简体中文",
      native_territory => "中国香港特别行政区",
    },
    {
      id               => "zh_Hans_MO",
      en_language      => "Chinese",
      en_script        => "Simplified\ Han",
      en_territory     => "Macau\ SAR\ China",
      native_language  => "中文",
      native_script    => "简体中文",
      native_territory => "中国澳门特别行政区",
    },
    {
      id               => "zh_Hans_SG",
      en_language      => "Chinese",
      en_script        => "Simplified\ Han",
      en_territory     => "Singapore",
      native_language  => "中文",
      native_script    => "简体中文",
      native_territory => "新加坡",
    },
    {
      id               => "zh_Hant",
      en_language      => "Chinese",
      en_script        => "Traditional\ Han",
      native_language  => "中文",
      native_script    => "繁體中文",
    },
    {
      id               => "zh_Hant_HK",
      en_language      => "Chinese",
      en_script        => "Traditional\ Han",
      en_territory     => "Hong\ Kong\ SAR\ China",
      native_language  => "中文",
      native_script    => "繁體中文",
      native_territory => "中華人民共和國香港特別行政區",
    },
    {
      id               => "zh_Hant_MO",
      en_language      => "Chinese",
      en_script        => "Traditional\ Han",
      en_territory     => "Macau\ SAR\ China",
      native_language  => "中文",
      native_script    => "繁體中文",
      native_territory => "中華人民共和國澳門特別行政區",
    },
    {
      id               => "zh_Hant_TW",
      en_language      => "Chinese",
      en_script        => "Traditional\ Han",
      en_territory     => "Taiwan",
      native_language  => "中文",
      native_script    => "繁體中文",
      native_territory => "台灣",
    },
    {
      id               => "zh_MO",
      en_language      => "Chinese",
      en_territory     => "Macau\ SAR\ China",
      native_language  => "中文",
      native_territory => "中華人民共和國澳門特別行政區",
    },
    {
      id               => "zh_SG",
      en_language      => "Chinese",
      en_territory     => "Singapore",
      native_language  => "中文",
      native_territory => "新加坡",
    },
    {
      id               => "zh_TW",
      en_language      => "Chinese",
      en_territory     => "Taiwan",
      native_language  => "中文",
      native_territory => "台灣",
    },
    {
      id               => "zu",
      en_language      => "Zulu",
      native_language  => "isiZulu",
    },
    {
      id               => "zu_ZA",
      en_language      => "Zulu",
      en_territory     => "South\ Africa",
      native_language  => "isiZulu",
      native_territory => "iNingizimu\ Afrika",
    },
);

%Aliases = (
    C => "en_US_POSIX",
    POSIX => "en_US_POSIX",
    aar => "aa",
    aar_DJ => "aa_DJ",
    aar_ER => "aa_ER",
    aar_ER_SAAHO => "aa_ER_SAAHO",
    aar_ET => "aa_ET",
    afr => "af",
    afr_NA => "af_NA",
    afr_ZA => "af_ZA",
    aka => "ak",
    aka_GH => "ak_GH",
    alb => "sq",
    alb_AL => "sq_AL",
    amh => "am",
    amh_ET => "am_ET",
    ara => "ar",
    ara_AE => "ar_AE",
    ara_BH => "ar_BH",
    ara_DZ => "ar_DZ",
    ara_EG => "ar_EG",
    ara_IQ => "ar_IQ",
    ara_JO => "ar_JO",
    ara_KW => "ar_KW",
    ara_LB => "ar_LB",
    ara_LY => "ar_LY",
    ara_MA => "ar_MA",
    ara_OM => "ar_OM",
    ara_QA => "ar_QA",
    ara_SA => "ar_SA",
    ara_SD => "ar_SD",
    ara_SY => "ar_SY",
    ara_TN => "ar_TN",
    ara_YE => "ar_YE",
    arm => "hy",
    arm_AM => "hy_AM",
    arm_AM_REVISED => "hy_AM_REVISED",
    asm => "as",
    asm_IN => "as_IN",
    aze => "az",
    aze_AZ => "az_AZ",
    aze_AZ_Cyrl => "az_Cyrl_AZ",
    aze_AZ_Latn => "az_Latn_AZ",
    aze_Cyrl => "az_Cyrl",
    aze_Latn => "az_Latn",
    baq => "eu",
    baq_ES => "eu_ES",
    bel => "be",
    bel_BY => "be_BY",
    ben => "bn",
    ben_BD => "bn_BD",
    ben_IN => "bn_IN",
    bos => "bs",
    bos_BA => "bs_BA",
    bul => "bg",
    bul_BG => "bg_BG",
    bur => "my",
    bur_MM => "my_MM",
    cat => "ca",
    cat_ES => "ca_ES",
    chi => "zh",
    chi_CN => "zh_CN",
    chi_CN_Hans => "zh_Hans_CN",
    chi_HK => "zh_HK",
    chi_HK_Hans => "zh_Hans_HK",
    chi_HK_Hant => "zh_Hant_HK",
    chi_Hans => "zh_Hans",
    chi_Hant => "zh_Hant",
    chi_MO => "zh_MO",
    chi_MO_Hans => "zh_Hans_MO",
    chi_MO_Hant => "zh_Hant_MO",
    chi_SG => "zh_SG",
    chi_SG_Hans => "zh_Hans_SG",
    chi_TW => "zh_TW",
    chi_TW_Hant => "zh_Hant_TW",
    cor => "kw",
    cor_GB => "kw_GB",
    cze => "cs",
    cze_CZ => "cs_CZ",
    dan => "da",
    dan_DK => "da_DK",
    div => "dv",
    div_MV => "dv_MV",
    dut => "nl",
    dut_BE => "nl_BE",
    dut_NL => "nl_NL",
    dzo => "dz",
    dzo_BT => "dz_BT",
    eng => "en",
    eng_AS => "en_AS",
    eng_AU => "en_AU",
    eng_BE => "en_BE",
    eng_BW => "en_BW",
    eng_BZ => "en_BZ",
    eng_CA => "en_CA",
    eng_Dsrt => "en_Dsrt",
    eng_GB => "en_GB",
    eng_GU => "en_GU",
    eng_HK => "en_HK",
    eng_IE => "en_IE",
    eng_IN => "en_IN",
    eng_JM => "en_JM",
    eng_MH => "en_MH",
    eng_MP => "en_MP",
    eng_MT => "en_MT",
    eng_NA => "en_NA",
    eng_NZ => "en_NZ",
    eng_PH => "en_PH",
    eng_PK => "en_PK",
    eng_SG => "en_SG",
    eng_Shaw => "en_Shaw",
    eng_TT => "en_TT",
    eng_UM => "en_UM",
    eng_US => "en_US",
    eng_US_Dsrt => "en_Dsrt_US",
    eng_US_POSIX => "en_US_POSIX",
    eng_VI => "en_VI",
    eng_ZA => "en_ZA",
    eng_ZW => "en_ZW",
    epo => "eo",
    est => "et",
    est_EE => "et_EE",
    ewe => "ee",
    ewe_GH => "ee_GH",
    ewe_TG => "ee_TG",
    fao => "fo",
    fao_FO => "fo_FO",
    fin => "fi",
    fin_FI => "fi_FI",
    fre => "fr",
    fre_BE => "fr_BE",
    fre_CA => "fr_CA",
    fre_CH => "fr_CH",
    fre_FR => "fr_FR",
    fre_LU => "fr_LU",
    fre_MC => "fr_MC",
    fre_SN => "fr_SN",
    geo => "ka",
    geo_GE => "ka_GE",
    ger => "de",
    ger_AT => "de_AT",
    ger_BE => "de_BE",
    ger_CH => "de_CH",
    ger_DE => "de_DE",
    ger_LI => "de_LI",
    ger_LU => "de_LU",
    gle => "ga",
    gle_IE => "ga_IE",
    glg => "gl",
    glg_ES => "gl_ES",
    glv => "gv",
    glv_GB => "gv_GB",
    gre => "el",
    gre_CY => "el_CY",
    gre_GR => "el_GR",
    gre_POLYTON => "el_POLYTON",
    guj => "gu",
    guj_IN => "gu_IN",
    hau => "ha",
    hau_Arab => "ha_Arab",
    hau_GH => "ha_GH",
    hau_GH_Latn => "ha_Latn_GH",
    hau_Latn => "ha_Latn",
    hau_NE => "ha_NE",
    hau_NE_Latn => "ha_Latn_NE",
    hau_NG => "ha_NG",
    hau_NG_Arab => "ha_Arab_NG",
    hau_NG_Latn => "ha_Latn_NG",
    hau_SD => "ha_SD",
    hau_SD_Arab => "ha_Arab_SD",
    heb => "he",
    heb_IL => "he_IL",
    hin => "hi",
    hin_IN => "hi_IN",
    hrv => "hr",
    hrv_HR => "hr_HR",
    hun => "hu",
    hun_HU => "hu_HU",
    ibo => "ig",
    ibo_NG => "ig_NG",
    ice => "is",
    ice_IS => "is_IS",
    iii => "ii",
    iii_CN => "ii_CN",
    iku => "iu",
    ina => "ia",
    ind => "id",
    ind_ID => "id_ID",
    ita => "it",
    ita_CH => "it_CH",
    ita_IT => "it_IT",
    iw => "he",
    iw_IL => "he_IL",
    jpn => "ja",
    jpn_JP => "ja_JP",
    kal => "kl",
    kal_GL => "kl_GL",
    kan => "kn",
    kan_IN => "kn_IN",
    kaz => "kk",
    kaz_Cyrl => "kk_Cyrl",
    kaz_KZ => "kk_KZ",
    kaz_KZ_Cyrl => "kk_Cyrl_KZ",
    khm => "km",
    khm_KH => "km_KH",
    kin => "rw",
    kin_RW => "rw_RW",
    kir => "ky",
    kir_KG => "ky_KG",
    kor => "ko",
    kor_KR => "ko_KR",
    kur => "ku",
    kur_Arab => "ku_Arab",
    kur_IQ => "ku_IQ",
    kur_IQ_Arab => "ku_Arab_IQ",
    kur_IR => "ku_IR",
    kur_IR_Arab => "ku_Arab_IR",
    kur_Latn => "ku_Latn",
    kur_SY => "ku_SY",
    kur_SY_Arab => "ku_Arab_SY",
    kur_TR => "ku_TR",
    kur_TR_Latn => "ku_Latn_TR",
    lao => "lo",
    lao_LA => "lo_LA",
    lav => "lv",
    lav_LV => "lv_LV",
    lin => "ln",
    lin_CD => "ln_CD",
    lin_CG => "ln_CG",
    lit => "lt",
    lit_LT => "lt_LT",
    mac => "mk",
    mac_MK => "mk_MK",
    mal => "ml",
    mal_IN => "ml_IN",
    mar => "mr",
    mar_IN => "mr_IN",
    may => "ms",
    may_BN => "ms_BN",
    may_MY => "ms_MY",
    mlt => "mt",
    mlt_MT => "mt_MT",
    mon => "mn",
    mon_CN => "mn_CN",
    mon_CN_Mong => "mn_Mong_CN",
    mon_Cyrl => "mn_Cyrl",
    mon_MN => "mn_MN",
    mon_MN_Cyrl => "mn_Cyrl_MN",
    mon_Mong => "mn_Mong",
    nbl => "nr",
    nbl_ZA => "nr_ZA",
    nep => "ne",
    nep_IN => "ne_IN",
    nep_NP => "ne_NP",
    nno => "nn",
    nno_NO => "nn_NO",
    no => "nn",
    no_NO => "nn_NO",
    no_NO_NY => "nn_NO",
    nob => "nb",
    nob_NO => "nb_NO",
    nor => "no",
    nya => "ny",
    nya_MW => "ny_MW",
    oci => "oc",
    oci_FR => "oc_FR",
    ori => "or",
    ori_IN => "or_IN",
    orm => "om",
    orm_ET => "om_ET",
    orm_KE => "om_KE",
    pan => "pa",
    pan_Arab => "pa_Arab",
    pan_Guru => "pa_Guru",
    pan_IN => "pa_IN",
    pan_IN_Guru => "pa_Guru_IN",
    pan_PK => "pa_PK",
    pan_PK_Arab => "pa_Arab_PK",
    per => "fa",
    per_AF => "fa_AF",
    per_IR => "fa_IR",
    pol => "pl",
    pol_PL => "pl_PL",
    por => "pt",
    por_BR => "pt_BR",
    por_PT => "pt_PT",
    pus => "ps",
    pus_AF => "ps_AF",
    rum => "ro",
    rum_MD => "ro_MD",
    rum_RO => "ro_RO",
    rus => "ru",
    rus_RU => "ru_RU",
    rus_UA => "ru_UA",
    san => "sa",
    san_IN => "sa_IN",
    sin => "si",
    sin_LK => "si_LK",
    slo => "sk",
    slo_SK => "sk_SK",
    slv => "sl",
    slv_SI => "sl_SI",
    sme => "se",
    sme_FI => "se_FI",
    sme_NO => "se_NO",
    som => "so",
    som_DJ => "so_DJ",
    som_ET => "so_ET",
    som_KE => "so_KE",
    som_SO => "so_SO",
    sot => "st",
    sot_LS => "st_LS",
    sot_ZA => "st_ZA",
    spa => "es",
    spa_AR => "es_AR",
    spa_BO => "es_BO",
    spa_CL => "es_CL",
    spa_CO => "es_CO",
    spa_CR => "es_CR",
    spa_DO => "es_DO",
    spa_EC => "es_EC",
    spa_ES => "es_ES",
    spa_GT => "es_GT",
    spa_HN => "es_HN",
    spa_MX => "es_MX",
    spa_NI => "es_NI",
    spa_PA => "es_PA",
    spa_PE => "es_PE",
    spa_PR => "es_PR",
    spa_PY => "es_PY",
    spa_SV => "es_SV",
    spa_US => "es_US",
    spa_UY => "es_UY",
    spa_VE => "es_VE",
    srp => "sr",
    srp_BA => "sr_BA",
    srp_BA_Cyrl => "sr_Cyrl_BA",
    srp_BA_Latn => "sr_Latn_BA",
    srp_CS => "sr_CS",
    srp_CS_Cyrl => "sr_Cyrl_CS",
    srp_CS_Latn => "sr_Latn_CS",
    srp_Cyrl => "sr_Cyrl",
    srp_Latn => "sr_Latn",
    srp_ME => "sr_ME",
    srp_ME_Cyrl => "sr_Cyrl_ME",
    srp_ME_Latn => "sr_Latn_ME",
    srp_RS => "sr_RS",
    srp_RS_Cyrl => "sr_Cyrl_RS",
    srp_RS_Latn => "sr_Latn_RS",
    srp_YU => "sr_YU",
    srp_YU_Cyrl => "sr_Cyrl_YU",
    srp_YU_Latn => "sr_Latn_YU",
    ssw => "ss",
    ssw_SZ => "ss_SZ",
    ssw_ZA => "ss_ZA",
    swa => "sw",
    swa_KE => "sw_KE",
    swa_TZ => "sw_TZ",
    swe => "sv",
    swe_FI => "sv_FI",
    swe_SE => "sv_SE",
    tam => "ta",
    tam_IN => "ta_IN",
    tat => "tt",
    tat_RU => "tt_RU",
    tel => "te",
    tel_IN => "te_IN",
    tgk => "tg",
    tgk_Cyrl => "tg_Cyrl",
    tgk_TJ => "tg_TJ",
    tgk_TJ_Cyrl => "tg_Cyrl_TJ",
    tgl => "tl",
    tha => "th",
    tha_TH => "th_TH",
    tib => "bo",
    tib_CN => "bo_CN",
    tib_IN => "bo_IN",
    tir => "ti",
    tir_ER => "ti_ER",
    tir_ET => "ti_ET",
    ton => "to",
    ton_TO => "to_TO",
    tsn => "tn",
    tsn_ZA => "tn_ZA",
    tso => "ts",
    tso_ZA => "ts_ZA",
    tur => "tr",
    tur_TR => "tr_TR",
    uig => "ug",
    uig_Arab => "ug_Arab",
    uig_CN => "ug_CN",
    uig_CN_Arab => "ug_Arab_CN",
    ukr => "uk",
    ukr_UA => "uk_UA",
    urd => "ur",
    urd_IN => "ur_IN",
    urd_PK => "ur_PK",
    uzb => "uz",
    uzb_AF => "uz_AF",
    uzb_AF_Arab => "uz_Arab_AF",
    uzb_Arab => "uz_Arab",
    uzb_Cyrl => "uz_Cyrl",
    uzb_Latn => "uz_Latn",
    uzb_UZ => "uz_UZ",
    uzb_UZ_Cyrl => "uz_Cyrl_UZ",
    uzb_UZ_Latn => "uz_Latn_UZ",
    ven => "ve",
    ven_ZA => "ve_ZA",
    vie => "vi",
    vie_VN => "vi_VN",
    wel => "cy",
    wel_GB => "cy_GB",
    wol => "wo",
    wol_Latn => "wo_Latn",
    wol_SN => "wo_SN",
    wol_SN_Latn => "wo_Latn_SN",
    xho => "xh",
    xho_ZA => "xh_ZA",
    yor => "yo",
    yor_NG => "yo_NG",
    zul => "zu",
    zul_ZA => "zu_ZA",
);

1;

__END__

=head1 NAME

DateTime::Locale::Catalog - Provides a list of all valid locale names

=head1 SYNOPSIS

See DateTime::Locale for usage details.

=head1 DESCRIPTION

This module contains a list of all known locales.

=head1 LOCALES

Any method taking locale id or name arguments should use one of the
values listed below. Ids and names are case sensitive. The id starts
with the ISO639-1 language code, and may also include information
identifying any or all of territory, script, or variant.

Always select the closest matching locale - for example, French
Canadians would choose fr_CA over fr - and B<always> use locale ids in
preference to names; locale ids offer greater compatibility when using
localized third party modules.

The available locales are:

 Locale id           Locale name
 ==================================================
 aa                  Afar
 aa_DJ               Afar Djibouti
 aa_ER               Afar Eritrea
 aa_ER_SAAHO         Afar Eritrea Saho
 aa_ET               Afar Ethiopia
 af                  Afrikaans
 af_NA               Afrikaans Namibia
 af_ZA               Afrikaans South Africa
 ak                  Akan
 ak_GH               Akan Ghana
 am                  Amharic
 am_ET               Amharic Ethiopia
 ar                  Arabic
 ar_AE               Arabic United Arab Emirates
 ar_BH               Arabic Bahrain
 ar_DZ               Arabic Algeria
 ar_EG               Arabic Egypt
 ar_IQ               Arabic Iraq
 ar_JO               Arabic Jordan
 ar_KW               Arabic Kuwait
 ar_LB               Arabic Lebanon
 ar_LY               Arabic Libya
 ar_MA               Arabic Morocco
 ar_OM               Arabic Oman
 ar_QA               Arabic Qatar
 ar_SA               Arabic Saudi Arabia
 ar_SD               Arabic Sudan
 ar_SY               Arabic Syria
 ar_TN               Arabic Tunisia
 ar_YE               Arabic Yemen
 as                  Assamese
 as_IN               Assamese India
 az                  Azerbaijani
 az_AZ               Azerbaijani Azerbaijan
 az_Cyrl             Azerbaijani (Cyrillic)
 az_Cyrl_AZ          Azerbaijani Azerbaijan (Cyrillic)
 az_Latn             Azerbaijani (Latin)
 az_Latn_AZ          Azerbaijani Azerbaijan (Latin)
 be                  Belarusian
 be_BY               Belarusian Belarus
 bg                  Bulgarian
 bg_BG               Bulgarian Bulgaria
 bn                  Bengali
 bn_BD               Bengali Bangladesh
 bn_IN               Bengali India
 bo                  Tibetan
 bo_CN               Tibetan China
 bo_IN               Tibetan India
 bs                  Bosnian
 bs_BA               Bosnian Bosnia and Herzegovina
 byn                 Blin
 byn_ER              Blin Eritrea
 ca                  Catalan
 ca_ES               Catalan Spain
 cch                 Atsam
 cch_NG              Atsam Nigeria
 cop                 Coptic
 cs                  Czech
 cs_CZ               Czech Czech Republic
 cy                  Welsh
 cy_GB               Welsh United Kingdom
 da                  Danish
 da_DK               Danish Denmark
 de                  German
 de_AT               German Austria
 de_BE               German Belgium
 de_CH               German Switzerland
 de_DE               German Germany
 de_LI               German Liechtenstein
 de_LU               German Luxembourg
 dv                  Divehi
 dv_MV               Divehi Maldives
 dz                  Dzongkha
 dz_BT               Dzongkha Bhutan
 ee                  Ewe
 ee_GH               Ewe Ghana
 ee_TG               Ewe Togo
 el                  Greek
 el_CY               Greek Cyprus
 el_GR               Greek Greece
 el_POLYTON          Greek
 en                  English
 en_AS               English American Samoa
 en_AU               English Australia
 en_BE               English Belgium
 en_BW               English Botswana
 en_BZ               English Belize
 en_CA               English Canada
 en_Dsrt             English (Deseret)
 en_Dsrt_US          English United States (Deseret)
 en_GB               English United Kingdom
 en_GU               English Guam
 en_HK               English Hong Kong SAR China
 en_IE               English Ireland
 en_IN               English India
 en_JM               English Jamaica
 en_MH               English Marshall Islands
 en_MP               English Northern Mariana Islands
 en_MT               English Malta
 en_NA               English Namibia
 en_NZ               English New Zealand
 en_PH               English Philippines
 en_PK               English Pakistan
 en_SG               English Singapore
 en_Shaw             English (Shavian)
 en_TT               English Trinidad and Tobago
 en_UM               English U.S. Minor Outlying Islands
 en_US               English United States
 en_US_POSIX         English United States Computer
 en_VI               English U.S. Virgin Islands
 en_ZA               English South Africa
 en_ZW               English Zimbabwe
 eo                  Esperanto
 es                  Spanish
 es_AR               Spanish Argentina
 es_BO               Spanish Bolivia
 es_CL               Spanish Chile
 es_CO               Spanish Colombia
 es_CR               Spanish Costa Rica
 es_DO               Spanish Dominican Republic
 es_EC               Spanish Ecuador
 es_ES               Spanish Spain
 es_GT               Spanish Guatemala
 es_HN               Spanish Honduras
 es_MX               Spanish Mexico
 es_NI               Spanish Nicaragua
 es_PA               Spanish Panama
 es_PE               Spanish Peru
 es_PR               Spanish Puerto Rico
 es_PY               Spanish Paraguay
 es_SV               Spanish El Salvador
 es_US               Spanish United States
 es_UY               Spanish Uruguay
 es_VE               Spanish Venezuela
 et                  Estonian
 et_EE               Estonian Estonia
 eu                  Basque
 eu_ES               Basque Spain
 fa                  Persian
 fa_AF               Persian Afghanistan
 fa_IR               Persian Iran
 fi                  Finnish
 fi_FI               Finnish Finland
 fil                 Filipino
 fil_PH              Filipino Philippines
 fo                  Faroese
 fo_FO               Faroese Faroe Islands
 fr                  French
 fr_BE               French Belgium
 fr_CA               French Canada
 fr_CH               French Switzerland
 fr_FR               French France
 fr_LU               French Luxembourg
 fr_MC               French Monaco
 fr_SN               French Senegal
 fur                 Friulian
 fur_IT              Friulian Italy
 ga                  Irish
 ga_IE               Irish Ireland
 gaa                 Ga
 gaa_GH              Ga Ghana
 gez                 Geez
 gez_ER              Geez Eritrea
 gez_ET              Geez Ethiopia
 gl                  Galician
 gl_ES               Galician Spain
 gsw                 Swiss German
 gsw_CH              Swiss German Switzerland
 gu                  Gujarati
 gu_IN               Gujarati India
 gv                  Manx
 gv_GB               Manx United Kingdom
 ha                  Hausa
 ha_Arab             Hausa (Arabic)
 ha_Arab_NG          Hausa Nigeria (Arabic)
 ha_Arab_SD          Hausa Sudan (Arabic)
 ha_GH               Hausa Ghana
 ha_Latn             Hausa (Latin)
 ha_Latn_GH          Hausa Ghana (Latin)
 ha_Latn_NE          Hausa Niger (Latin)
 ha_Latn_NG          Hausa Nigeria (Latin)
 ha_NE               Hausa Niger
 ha_NG               Hausa Nigeria
 ha_SD               Hausa Sudan
 haw                 Hawaiian
 haw_US              Hawaiian United States
 he                  Hebrew
 he_IL               Hebrew Israel
 hi                  Hindi
 hi_IN               Hindi India
 hr                  Croatian
 hr_HR               Croatian Croatia
 hu                  Hungarian
 hu_HU               Hungarian Hungary
 hy                  Armenian
 hy_AM               Armenian Armenia
 hy_AM_REVISED       Armenian Armenia Revised Orthography
 ia                  Interlingua
 id                  Indonesian
 id_ID               Indonesian Indonesia
 ig                  Igbo
 ig_NG               Igbo Nigeria
 ii                  Sichuan Yi
 ii_CN               Sichuan Yi China
 is                  Icelandic
 is_IS               Icelandic Iceland
 it                  Italian
 it_CH               Italian Switzerland
 it_IT               Italian Italy
 iu                  Inuktitut
 ja                  Japanese
 ja_JP               Japanese Japan
 ka                  Georgian
 ka_GE               Georgian Georgia
 kaj                 Jju
 kaj_NG              Jju Nigeria
 kam                 Kamba
 kam_KE              Kamba Kenya
 kcg                 Tyap
 kcg_NG              Tyap Nigeria
 kfo                 Koro
 kfo_CI              Koro Côte d’Ivoire
 kk                  Kazakh
 kk_Cyrl             Kazakh (Cyrillic)
 kk_Cyrl_KZ          Kazakh Kazakhstan (Cyrillic)
 kk_KZ               Kazakh Kazakhstan
 kl                  Kalaallisut
 kl_GL               Kalaallisut Greenland
 km                  Khmer
 km_KH               Khmer Cambodia
 kn                  Kannada
 kn_IN               Kannada India
 ko                  Korean
 ko_KR               Korean South Korea
 kok                 Konkani
 kok_IN              Konkani India
 kpe                 Kpelle
 kpe_GN              Kpelle Guinea
 kpe_LR              Kpelle Liberia
 ku                  Kurdish
 ku_Arab             Kurdish (Arabic)
 ku_Arab_IQ          Kurdish Iraq (Arabic)
 ku_Arab_IR          Kurdish Iran (Arabic)
 ku_Arab_SY          Kurdish Syria (Arabic)
 ku_IQ               Kurdish Iraq
 ku_IR               Kurdish Iran
 ku_Latn             Kurdish (Latin)
 ku_Latn_TR          Kurdish Turkey (Latin)
 ku_SY               Kurdish Syria
 ku_TR               Kurdish Turkey
 kw                  Cornish
 kw_GB               Cornish United Kingdom
 ky                  Kirghiz
 ky_KG               Kirghiz Kyrgyzstan
 ln                  Lingala
 ln_CD               Lingala Congo - Kinshasa
 ln_CG               Lingala Congo - Brazzaville
 lo                  Lao
 lo_LA               Lao Laos
 lt                  Lithuanian
 lt_LT               Lithuanian Lithuania
 lv                  Latvian
 lv_LV               Latvian Latvia
 mk                  Macedonian
 mk_MK               Macedonian Macedonia
 ml                  Malayalam
 ml_IN               Malayalam India
 mn                  Mongolian
 mn_CN               Mongolian China
 mn_Cyrl             Mongolian (Cyrillic)
 mn_Cyrl_MN          Mongolian Mongolia (Cyrillic)
 mn_MN               Mongolian Mongolia
 mn_Mong             Mongolian (Mongolian)
 mn_Mong_CN          Mongolian China (Mongolian)
 mo                  Moldavian
 mr                  Marathi
 mr_IN               Marathi India
 ms                  Malay
 ms_BN               Malay Brunei
 ms_MY               Malay Malaysia
 mt                  Maltese
 mt_MT               Maltese Malta
 my                  Burmese
 my_MM               Burmese Myanmar [Burma]
 nb                  Norwegian Bokmål
 nb_NO               Norwegian Bokmål Norway
 nds                 Low German
 nds_DE              Low German Germany
 ne                  Nepali
 ne_IN               Nepali India
 ne_NP               Nepali Nepal
 nl                  Dutch
 nl_BE               Dutch Belgium
 nl_NL               Dutch Netherlands
 nn                  Norwegian Nynorsk
 nn_NO               Norwegian Nynorsk Norway
 no                  Norwegian
 nr                  South Ndebele
 nr_ZA               South Ndebele South Africa
 nso                 Northern Sotho
 nso_ZA              Northern Sotho South Africa
 ny                  Nyanja
 ny_MW               Nyanja Malawi
 oc                  Occitan
 oc_FR               Occitan France
 om                  Oromo
 om_ET               Oromo Ethiopia
 om_KE               Oromo Kenya
 or                  Oriya
 or_IN               Oriya India
 pa                  Punjabi
 pa_Arab             Punjabi (Arabic)
 pa_Arab_PK          Punjabi Pakistan (Arabic)
 pa_Guru             Punjabi (Gurmukhi)
 pa_Guru_IN          Punjabi India (Gurmukhi)
 pa_IN               Punjabi India
 pa_PK               Punjabi Pakistan
 pl                  Polish
 pl_PL               Polish Poland
 ps                  Pashto
 ps_AF               Pashto Afghanistan
 pt                  Portuguese
 pt_BR               Portuguese Brazil
 pt_PT               Portuguese Portugal
 ro                  Romanian
 ro_MD               Romanian Moldova
 ro_RO               Romanian Romania
 root                Root
 ru                  Russian
 ru_RU               Russian Russia
 ru_UA               Russian Ukraine
 rw                  Kinyarwanda
 rw_RW               Kinyarwanda Rwanda
 sa                  Sanskrit
 sa_IN               Sanskrit India
 se                  Northern Sami
 se_FI               Northern Sami Finland
 se_NO               Northern Sami Norway
 sh                  Serbo-Croatian
 sh_BA               Serbo-Croatian Bosnia and Herzegovina
 sh_CS               Serbo-Croatian Serbia and Montenegro
 sh_YU               Serbo-Croatian
 si                  Sinhala
 si_LK               Sinhala Sri Lanka
 sid                 Sidamo
 sid_ET              Sidamo Ethiopia
 sk                  Slovak
 sk_SK               Slovak Slovakia
 sl                  Slovenian
 sl_SI               Slovenian Slovenia
 so                  Somali
 so_DJ               Somali Djibouti
 so_ET               Somali Ethiopia
 so_KE               Somali Kenya
 so_SO               Somali Somalia
 sq                  Albanian
 sq_AL               Albanian Albania
 sr                  Serbian
 sr_BA               Serbian Bosnia and Herzegovina
 sr_CS               Serbian Serbia and Montenegro
 sr_Cyrl             Serbian (Cyrillic)
 sr_Cyrl_BA          Serbian Bosnia and Herzegovina (Cyrillic)
 sr_Cyrl_CS          Serbian Serbia and Montenegro (Cyrillic)
 sr_Cyrl_ME          Serbian Montenegro (Cyrillic)
 sr_Cyrl_RS          Serbian Serbia (Cyrillic)
 sr_Cyrl_YU          Serbian (Cyrillic)
 sr_Latn             Serbian (Latin)
 sr_Latn_BA          Serbian Bosnia and Herzegovina (Latin)
 sr_Latn_CS          Serbian Serbia and Montenegro (Latin)
 sr_Latn_ME          Serbian Montenegro (Latin)
 sr_Latn_RS          Serbian Serbia (Latin)
 sr_Latn_YU          Serbian (Latin)
 sr_ME               Serbian Montenegro
 sr_RS               Serbian Serbia
 sr_YU               Serbian
 ss                  Swati
 ss_SZ               Swati Swaziland
 ss_ZA               Swati South Africa
 st                  Southern Sotho
 st_LS               Southern Sotho Lesotho
 st_ZA               Southern Sotho South Africa
 sv                  Swedish
 sv_FI               Swedish Finland
 sv_SE               Swedish Sweden
 sw                  Swahili
 sw_KE               Swahili Kenya
 sw_TZ               Swahili Tanzania
 syr                 Syriac
 syr_SY              Syriac Syria
 ta                  Tamil
 ta_IN               Tamil India
 te                  Telugu
 te_IN               Telugu India
 tg                  Tajik
 tg_Cyrl             Tajik (Cyrillic)
 tg_Cyrl_TJ          Tajik Tajikistan (Cyrillic)
 tg_TJ               Tajik Tajikistan
 th                  Thai
 th_TH               Thai Thailand
 ti                  Tigrinya
 ti_ER               Tigrinya Eritrea
 ti_ET               Tigrinya Ethiopia
 tig                 Tigre
 tig_ER              Tigre Eritrea
 tl                  Tagalog
 tn                  Tswana
 tn_ZA               Tswana South Africa
 to                  Tonga
 to_TO               Tonga Tonga
 tr                  Turkish
 tr_TR               Turkish Turkey
 trv                 Taroko
 trv_TW              Taroko Taiwan
 ts                  Tsonga
 ts_ZA               Tsonga South Africa
 tt                  Tatar
 tt_RU               Tatar Russia
 ug                  Uighur
 ug_Arab             Uighur (Arabic)
 ug_Arab_CN          Uighur China (Arabic)
 ug_CN               Uighur China
 uk                  Ukrainian
 uk_UA               Ukrainian Ukraine
 ur                  Urdu
 ur_IN               Urdu India
 ur_PK               Urdu Pakistan
 uz                  Uzbek
 uz_AF               Uzbek Afghanistan
 uz_Arab             Uzbek (Arabic)
 uz_Arab_AF          Uzbek Afghanistan (Arabic)
 uz_Cyrl             Uzbek (Cyrillic)
 uz_Cyrl_UZ          Uzbek Uzbekistan (Cyrillic)
 uz_Latn             Uzbek (Latin)
 uz_Latn_UZ          Uzbek Uzbekistan (Latin)
 uz_UZ               Uzbek Uzbekistan
 ve                  Venda
 ve_ZA               Venda South Africa
 vi                  Vietnamese
 vi_VN               Vietnamese Vietnam
 wal                 Walamo
 wal_ET              Walamo Ethiopia
 wo                  Wolof
 wo_Latn             Wolof (Latin)
 wo_Latn_SN          Wolof Senegal (Latin)
 wo_SN               Wolof Senegal
 xh                  Xhosa
 xh_ZA               Xhosa South Africa
 yo                  Yoruba
 yo_NG               Yoruba Nigeria
 zh                  Chinese
 zh_CN               Chinese China
 zh_HK               Chinese Hong Kong SAR China
 zh_Hans             Chinese (Simplified Han)
 zh_Hans_CN          Chinese China (Simplified Han)
 zh_Hans_HK          Chinese Hong Kong SAR China (Simplified Han)
 zh_Hans_MO          Chinese Macau SAR China (Simplified Han)
 zh_Hans_SG          Chinese Singapore (Simplified Han)
 zh_Hant             Chinese (Traditional Han)
 zh_Hant_HK          Chinese Hong Kong SAR China (Traditional Han)
 zh_Hant_MO          Chinese Macau SAR China (Traditional Han)
 zh_Hant_TW          Chinese Taiwan (Traditional Han)
 zh_MO               Chinese Macau SAR China
 zh_SG               Chinese Singapore
 zh_TW               Chinese Taiwan
 zu                  Zulu
 zu_ZA               Zulu South Africa


There are also many aliases available, mostly for three-letter
(ISO639-2) language codes, these are:

 Locale id           Is an alias for
 ==================================================
 C                   en_US_POSIX
 POSIX               en_US_POSIX
 aar                 aa
 aar_DJ              aa_DJ
 aar_ER              aa_ER
 aar_ER_SAAHO        aa_ER_SAAHO
 aar_ET              aa_ET
 afr                 af
 afr_NA              af_NA
 afr_ZA              af_ZA
 aka                 ak
 aka_GH              ak_GH
 alb                 sq
 alb_AL              sq_AL
 amh                 am
 amh_ET              am_ET
 ara                 ar
 ara_AE              ar_AE
 ara_BH              ar_BH
 ara_DZ              ar_DZ
 ara_EG              ar_EG
 ara_IQ              ar_IQ
 ara_JO              ar_JO
 ara_KW              ar_KW
 ara_LB              ar_LB
 ara_LY              ar_LY
 ara_MA              ar_MA
 ara_OM              ar_OM
 ara_QA              ar_QA
 ara_SA              ar_SA
 ara_SD              ar_SD
 ara_SY              ar_SY
 ara_TN              ar_TN
 ara_YE              ar_YE
 arm                 hy
 arm_AM              hy_AM
 arm_AM_REVISED      hy_AM_REVISED
 asm                 as
 asm_IN              as_IN
 aze                 az
 aze_AZ              az_AZ
 aze_AZ_Cyrl         az_Cyrl_AZ
 aze_AZ_Latn         az_Latn_AZ
 aze_Cyrl            az_Cyrl
 aze_Latn            az_Latn
 baq                 eu
 baq_ES              eu_ES
 bel                 be
 bel_BY              be_BY
 ben                 bn
 ben_BD              bn_BD
 ben_IN              bn_IN
 bos                 bs
 bos_BA              bs_BA
 bul                 bg
 bul_BG              bg_BG
 bur                 my
 bur_MM              my_MM
 cat                 ca
 cat_ES              ca_ES
 chi                 zh
 chi_CN              zh_CN
 chi_CN_Hans         zh_Hans_CN
 chi_HK              zh_HK
 chi_HK_Hans         zh_Hans_HK
 chi_HK_Hant         zh_Hant_HK
 chi_Hans            zh_Hans
 chi_Hant            zh_Hant
 chi_MO              zh_MO
 chi_MO_Hans         zh_Hans_MO
 chi_MO_Hant         zh_Hant_MO
 chi_SG              zh_SG
 chi_SG_Hans         zh_Hans_SG
 chi_TW              zh_TW
 chi_TW_Hant         zh_Hant_TW
 cor                 kw
 cor_GB              kw_GB
 cze                 cs
 cze_CZ              cs_CZ
 dan                 da
 dan_DK              da_DK
 div                 dv
 div_MV              dv_MV
 dut                 nl
 dut_BE              nl_BE
 dut_NL              nl_NL
 dzo                 dz
 dzo_BT              dz_BT
 eng                 en
 eng_AS              en_AS
 eng_AU              en_AU
 eng_BE              en_BE
 eng_BW              en_BW
 eng_BZ              en_BZ
 eng_CA              en_CA
 eng_Dsrt            en_Dsrt
 eng_GB              en_GB
 eng_GU              en_GU
 eng_HK              en_HK
 eng_IE              en_IE
 eng_IN              en_IN
 eng_JM              en_JM
 eng_MH              en_MH
 eng_MP              en_MP
 eng_MT              en_MT
 eng_NA              en_NA
 eng_NZ              en_NZ
 eng_PH              en_PH
 eng_PK              en_PK
 eng_SG              en_SG
 eng_Shaw            en_Shaw
 eng_TT              en_TT
 eng_UM              en_UM
 eng_US              en_US
 eng_US_Dsrt         en_Dsrt_US
 eng_US_POSIX        en_US_POSIX
 eng_VI              en_VI
 eng_ZA              en_ZA
 eng_ZW              en_ZW
 epo                 eo
 est                 et
 est_EE              et_EE
 ewe                 ee
 ewe_GH              ee_GH
 ewe_TG              ee_TG
 fao                 fo
 fao_FO              fo_FO
 fin                 fi
 fin_FI              fi_FI
 fre                 fr
 fre_BE              fr_BE
 fre_CA              fr_CA
 fre_CH              fr_CH
 fre_FR              fr_FR
 fre_LU              fr_LU
 fre_MC              fr_MC
 fre_SN              fr_SN
 geo                 ka
 geo_GE              ka_GE
 ger                 de
 ger_AT              de_AT
 ger_BE              de_BE
 ger_CH              de_CH
 ger_DE              de_DE
 ger_LI              de_LI
 ger_LU              de_LU
 gle                 ga
 gle_IE              ga_IE
 glg                 gl
 glg_ES              gl_ES
 glv                 gv
 glv_GB              gv_GB
 gre                 el
 gre_CY              el_CY
 gre_GR              el_GR
 gre_POLYTON         el_POLYTON
 guj                 gu
 guj_IN              gu_IN
 hau                 ha
 hau_Arab            ha_Arab
 hau_GH              ha_GH
 hau_GH_Latn         ha_Latn_GH
 hau_Latn            ha_Latn
 hau_NE              ha_NE
 hau_NE_Latn         ha_Latn_NE
 hau_NG              ha_NG
 hau_NG_Arab         ha_Arab_NG
 hau_NG_Latn         ha_Latn_NG
 hau_SD              ha_SD
 hau_SD_Arab         ha_Arab_SD
 heb                 he
 heb_IL              he_IL
 hin                 hi
 hin_IN              hi_IN
 hrv                 hr
 hrv_HR              hr_HR
 hun                 hu
 hun_HU              hu_HU
 ibo                 ig
 ibo_NG              ig_NG
 ice                 is
 ice_IS              is_IS
 iii                 ii
 iii_CN              ii_CN
 iku                 iu
 ina                 ia
 ind                 id
 ind_ID              id_ID
 ita                 it
 ita_CH              it_CH
 ita_IT              it_IT
 iw                  he
 iw_IL               he_IL
 jpn                 ja
 jpn_JP              ja_JP
 kal                 kl
 kal_GL              kl_GL
 kan                 kn
 kan_IN              kn_IN
 kaz                 kk
 kaz_Cyrl            kk_Cyrl
 kaz_KZ              kk_KZ
 kaz_KZ_Cyrl         kk_Cyrl_KZ
 khm                 km
 khm_KH              km_KH
 kin                 rw
 kin_RW              rw_RW
 kir                 ky
 kir_KG              ky_KG
 kor                 ko
 kor_KR              ko_KR
 kur                 ku
 kur_Arab            ku_Arab
 kur_IQ              ku_IQ
 kur_IQ_Arab         ku_Arab_IQ
 kur_IR              ku_IR
 kur_IR_Arab         ku_Arab_IR
 kur_Latn            ku_Latn
 kur_SY              ku_SY
 kur_SY_Arab         ku_Arab_SY
 kur_TR              ku_TR
 kur_TR_Latn         ku_Latn_TR
 lao                 lo
 lao_LA              lo_LA
 lav                 lv
 lav_LV              lv_LV
 lin                 ln
 lin_CD              ln_CD
 lin_CG              ln_CG
 lit                 lt
 lit_LT              lt_LT
 mac                 mk
 mac_MK              mk_MK
 mal                 ml
 mal_IN              ml_IN
 mar                 mr
 mar_IN              mr_IN
 may                 ms
 may_BN              ms_BN
 may_MY              ms_MY
 mlt                 mt
 mlt_MT              mt_MT
 mon                 mn
 mon_CN              mn_CN
 mon_CN_Mong         mn_Mong_CN
 mon_Cyrl            mn_Cyrl
 mon_MN              mn_MN
 mon_MN_Cyrl         mn_Cyrl_MN
 mon_Mong            mn_Mong
 nbl                 nr
 nbl_ZA              nr_ZA
 nep                 ne
 nep_IN              ne_IN
 nep_NP              ne_NP
 nno                 nn
 nno_NO              nn_NO
 no                  nn
 no_NO               nn_NO
 no_NO_NY            nn_NO
 nob                 nb
 nob_NO              nb_NO
 nor                 no
 nya                 ny
 nya_MW              ny_MW
 oci                 oc
 oci_FR              oc_FR
 ori                 or
 ori_IN              or_IN
 orm                 om
 orm_ET              om_ET
 orm_KE              om_KE
 pan                 pa
 pan_Arab            pa_Arab
 pan_Guru            pa_Guru
 pan_IN              pa_IN
 pan_IN_Guru         pa_Guru_IN
 pan_PK              pa_PK
 pan_PK_Arab         pa_Arab_PK
 per                 fa
 per_AF              fa_AF
 per_IR              fa_IR
 pol                 pl
 pol_PL              pl_PL
 por                 pt
 por_BR              pt_BR
 por_PT              pt_PT
 pus                 ps
 pus_AF              ps_AF
 rum                 ro
 rum_MD              ro_MD
 rum_RO              ro_RO
 rus                 ru
 rus_RU              ru_RU
 rus_UA              ru_UA
 san                 sa
 san_IN              sa_IN
 sin                 si
 sin_LK              si_LK
 slo                 sk
 slo_SK              sk_SK
 slv                 sl
 slv_SI              sl_SI
 sme                 se
 sme_FI              se_FI
 sme_NO              se_NO
 som                 so
 som_DJ              so_DJ
 som_ET              so_ET
 som_KE              so_KE
 som_SO              so_SO
 sot                 st
 sot_LS              st_LS
 sot_ZA              st_ZA
 spa                 es
 spa_AR              es_AR
 spa_BO              es_BO
 spa_CL              es_CL
 spa_CO              es_CO
 spa_CR              es_CR
 spa_DO              es_DO
 spa_EC              es_EC
 spa_ES              es_ES
 spa_GT              es_GT
 spa_HN              es_HN
 spa_MX              es_MX
 spa_NI              es_NI
 spa_PA              es_PA
 spa_PE              es_PE
 spa_PR              es_PR
 spa_PY              es_PY
 spa_SV              es_SV
 spa_US              es_US
 spa_UY              es_UY
 spa_VE              es_VE
 srp                 sr
 srp_BA              sr_BA
 srp_BA_Cyrl         sr_Cyrl_BA
 srp_BA_Latn         sr_Latn_BA
 srp_CS              sr_CS
 srp_CS_Cyrl         sr_Cyrl_CS
 srp_CS_Latn         sr_Latn_CS
 srp_Cyrl            sr_Cyrl
 srp_Latn            sr_Latn
 srp_ME              sr_ME
 srp_ME_Cyrl         sr_Cyrl_ME
 srp_ME_Latn         sr_Latn_ME
 srp_RS              sr_RS
 srp_RS_Cyrl         sr_Cyrl_RS
 srp_RS_Latn         sr_Latn_RS
 srp_YU              sr_YU
 srp_YU_Cyrl         sr_Cyrl_YU
 srp_YU_Latn         sr_Latn_YU
 ssw                 ss
 ssw_SZ              ss_SZ
 ssw_ZA              ss_ZA
 swa                 sw
 swa_KE              sw_KE
 swa_TZ              sw_TZ
 swe                 sv
 swe_FI              sv_FI
 swe_SE              sv_SE
 tam                 ta
 tam_IN              ta_IN
 tat                 tt
 tat_RU              tt_RU
 tel                 te
 tel_IN              te_IN
 tgk                 tg
 tgk_Cyrl            tg_Cyrl
 tgk_TJ              tg_TJ
 tgk_TJ_Cyrl         tg_Cyrl_TJ
 tgl                 tl
 tha                 th
 tha_TH              th_TH
 tib                 bo
 tib_CN              bo_CN
 tib_IN              bo_IN
 tir                 ti
 tir_ER              ti_ER
 tir_ET              ti_ET
 ton                 to
 ton_TO              to_TO
 tsn                 tn
 tsn_ZA              tn_ZA
 tso                 ts
 tso_ZA              ts_ZA
 tur                 tr
 tur_TR              tr_TR
 uig                 ug
 uig_Arab            ug_Arab
 uig_CN              ug_CN
 uig_CN_Arab         ug_Arab_CN
 ukr                 uk
 ukr_UA              uk_UA
 urd                 ur
 urd_IN              ur_IN
 urd_PK              ur_PK
 uzb                 uz
 uzb_AF              uz_AF
 uzb_AF_Arab         uz_Arab_AF
 uzb_Arab            uz_Arab
 uzb_Cyrl            uz_Cyrl
 uzb_Latn            uz_Latn
 uzb_UZ              uz_UZ
 uzb_UZ_Cyrl         uz_Cyrl_UZ
 uzb_UZ_Latn         uz_Latn_UZ
 ven                 ve
 ven_ZA              ve_ZA
 vie                 vi
 vie_VN              vi_VN
 wel                 cy
 wel_GB              cy_GB
 wol                 wo
 wol_Latn            wo_Latn
 wol_SN              wo_SN
 wol_SN_Latn         wo_Latn_SN
 xho                 xh
 xho_ZA              xh_ZA
 yor                 yo
 yor_NG              yo_NG
 zul                 zu
 zul_ZA              zu_ZA


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
