###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file en_Shaw.xml
# The source file version number was 1.9, generated on
# 2009/05/05 23:06:35.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::en_Shaw;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::en';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "𐑨𐑥", "𐑐𐑥" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $day_format_abbreviated = [ "·𐑥𐑭", "·𐑑𐑵", "·𐑢𐑧", "·𐑔𐑻", "·𐑓𐑮", "·𐑕𐑨", "·𐑕𐑭" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "·𐑥𐑭𐑙𐑛𐑱", "·𐑑𐑵𐑟𐑛𐑱", "·𐑢𐑧𐑙𐑟𐑛𐑱", "·𐑔𐑻𐑟𐑛𐑱", "·𐑓𐑮𐑲𐑛𐑱", "·𐑕𐑨𐑛𐑻𐑛𐑱", "·𐑕𐑭𐑙𐑛𐑱" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "𐑥", "𐑑", "𐑢", "𐑔", "𐑓", "𐑕", "𐑕" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "𐑚·𐑒", "𐑨𐑛" ];
    sub era_abbreviated { return $era_abbreviated }
}
{
    my $era_narrow = [ "𐑚", "𐑨" ];
    sub era_narrow { return $era_narrow }
}
{
    my $era_wide = [ "𐑚𐑰𐑓𐑪𐑮\ ·𐑒𐑮𐑲𐑕𐑑", "𐑨𐑙𐑴\ 𐑛𐑪𐑥𐑦𐑙𐑰" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "·𐑡𐑨", "·𐑓𐑧", "·𐑥𐑸", "·𐑱𐑐", "·𐑥𐑱", "·𐑡𐑵", "·𐑡𐑫", "·𐑪𐑜", "·𐑕𐑧", "·𐑷𐑒", "·𐑯𐑴", "·𐑛𐑭" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "·𐑡𐑨𐑙𐑘𐑭𐑢𐑺𐑰", "·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰", "·𐑥𐑸𐑗", "·𐑱𐑐𐑮𐑭𐑤", "·𐑥𐑱", "·𐑡𐑵𐑯", "·𐑡𐑫𐑤𐑲", "·𐑪𐑜𐑭𐑕𐑑", "·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸", "·𐑷𐑒𐑑𐑴𐑚𐑸", "·𐑯𐑴𐑝𐑧𐑥𐑚𐑸", "·𐑛𐑭𐑕𐑧𐑥𐑚𐑸" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "𐑡", "𐑓", "𐑥", "𐑱", "𐑥", "𐑡", "𐑡", "𐑪", "𐑕", "𐑷", "𐑯", "𐑛" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "𐑒1", "𐑒2", "𐑒3", "𐑒4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}
{
    my $quarter_format_wide = [ "1𐑕𐑑\ 𐑒𐑢𐑸𐑛𐑸", "2𐑯𐑛\ 𐑒𐑢𐑸𐑛𐑸", "3𐑻𐑛\ 𐑒𐑢𐑸𐑛𐑸", "4𐑹𐑔\ 𐑒𐑢𐑸𐑛𐑸" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }


sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::en_Shaw

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'en_Shaw' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for English Shavian.

=head1 DATA

This locale inherits from the L<DateTime::Locale::en> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  ·𐑥𐑭𐑙𐑛𐑱
  ·𐑑𐑵𐑟𐑛𐑱
  ·𐑢𐑧𐑙𐑟𐑛𐑱
  ·𐑔𐑻𐑟𐑛𐑱
  ·𐑓𐑮𐑲𐑛𐑱
  ·𐑕𐑨𐑛𐑻𐑛𐑱
  ·𐑕𐑭𐑙𐑛𐑱

=head3 Abbreviated (format)

  ·𐑥𐑭
  ·𐑑𐑵
  ·𐑢𐑧
  ·𐑔𐑻
  ·𐑓𐑮
  ·𐑕𐑨
  ·𐑕𐑭

=head3 Narrow (format)

  𐑥
  𐑑
  𐑢
  𐑔
  𐑓
  𐑕
  𐑕

=head3 Wide (stand-alone)

  ·𐑥𐑭𐑙𐑛𐑱
  ·𐑑𐑵𐑟𐑛𐑱
  ·𐑢𐑧𐑙𐑟𐑛𐑱
  ·𐑔𐑻𐑟𐑛𐑱
  ·𐑓𐑮𐑲𐑛𐑱
  ·𐑕𐑨𐑛𐑻𐑛𐑱
  ·𐑕𐑭𐑙𐑛𐑱

=head3 Abbreviated (stand-alone)

  ·𐑥𐑭
  ·𐑑𐑵
  ·𐑢𐑧
  ·𐑔𐑻
  ·𐑓𐑮
  ·𐑕𐑨
  ·𐑕𐑭

=head3 Narrow (stand-alone)

  𐑥
  𐑑
  𐑢
  𐑔
  𐑓
  𐑕
  𐑕

=head2 Months

=head3 Wide (format)

  ·𐑡𐑨𐑙𐑘𐑭𐑢𐑺𐑰
  ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰
  ·𐑥𐑸𐑗
  ·𐑱𐑐𐑮𐑭𐑤
  ·𐑥𐑱
  ·𐑡𐑵𐑯
  ·𐑡𐑫𐑤𐑲
  ·𐑪𐑜𐑭𐑕𐑑
  ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸
  ·𐑷𐑒𐑑𐑴𐑚𐑸
  ·𐑯𐑴𐑝𐑧𐑥𐑚𐑸
  ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸

=head3 Abbreviated (format)

  ·𐑡𐑨
  ·𐑓𐑧
  ·𐑥𐑸
  ·𐑱𐑐
  ·𐑥𐑱
  ·𐑡𐑵
  ·𐑡𐑫
  ·𐑪𐑜
  ·𐑕𐑧
  ·𐑷𐑒
  ·𐑯𐑴
  ·𐑛𐑭

=head3 Narrow (format)

  𐑡
  𐑓
  𐑥
  𐑱
  𐑥
  𐑡
  𐑡
  𐑪
  𐑕
  𐑷
  𐑯
  𐑛

=head3 Wide (stand-alone)

  ·𐑡𐑨𐑙𐑘𐑭𐑢𐑺𐑰
  ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰
  ·𐑥𐑸𐑗
  ·𐑱𐑐𐑮𐑭𐑤
  ·𐑥𐑱
  ·𐑡𐑵𐑯
  ·𐑡𐑫𐑤𐑲
  ·𐑪𐑜𐑭𐑕𐑑
  ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸
  ·𐑷𐑒𐑑𐑴𐑚𐑸
  ·𐑯𐑴𐑝𐑧𐑥𐑚𐑸
  ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸

=head3 Abbreviated (stand-alone)

  ·𐑡𐑨
  ·𐑓𐑧
  ·𐑥𐑸
  ·𐑱𐑐
  ·𐑥𐑱
  ·𐑡𐑵
  ·𐑡𐑫
  ·𐑪𐑜
  ·𐑕𐑧
  ·𐑷𐑒
  ·𐑯𐑴
  ·𐑛𐑭

=head3 Narrow (stand-alone)

  𐑡
  𐑓
  𐑥
  𐑱
  𐑥
  𐑡
  𐑡
  𐑪
  𐑕
  𐑷
  𐑯
  𐑛

=head2 Quarters

=head3 Wide (format)

  1𐑕𐑑 𐑒𐑢𐑸𐑛𐑸
  2𐑯𐑛 𐑒𐑢𐑸𐑛𐑸
  3𐑻𐑛 𐑒𐑢𐑸𐑛𐑸
  4𐑹𐑔 𐑒𐑢𐑸𐑛𐑸

=head3 Abbreviated (format)

  𐑒1
  𐑒2
  𐑒3
  𐑒4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1𐑕𐑑 𐑒𐑢𐑸𐑛𐑸
  2𐑯𐑛 𐑒𐑢𐑸𐑛𐑸
  3𐑻𐑛 𐑒𐑢𐑸𐑛𐑸
  4𐑹𐑔 𐑒𐑢𐑸𐑛𐑸

=head3 Abbreviated (stand-alone)

  𐑒1
  𐑒2
  𐑒3
  𐑒4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  𐑚𐑰𐑓𐑪𐑮 ·𐑒𐑮𐑲𐑕𐑑
  𐑨𐑙𐑴 𐑛𐑪𐑥𐑦𐑙𐑰

=head3 Abbreviated

  𐑚·𐑒
  𐑨𐑛

=head3 Narrow

  𐑚
  𐑨

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = ·𐑑𐑵𐑟𐑛𐑱, ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰 5, 2008
   1995-12-22T09:05:02 = ·𐑓𐑮𐑲𐑛𐑱, ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸 22, 1995
  -0010-09-15T04:44:23 = ·𐑕𐑨𐑛𐑻𐑛𐑱, ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸 15, -10

=head3 Long

   2008-02-05T18:30:30 = ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰 5, 2008
   1995-12-22T09:05:02 = ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸 22, 1995
  -0010-09-15T04:44:23 = ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸 15, -10

=head3 Medium

   2008-02-05T18:30:30 = ·𐑓𐑧 5, 2008
   1995-12-22T09:05:02 = ·𐑛𐑭 22, 1995
  -0010-09-15T04:44:23 = ·𐑕𐑧 15, -10

=head3 Short

   2008-02-05T18:30:30 = 2/5/08
   1995-12-22T09:05:02 = 12/22/95
  -0010-09-15T04:44:23 = 9/15/-10

=head3 Default

   2008-02-05T18:30:30 = ·𐑓𐑧 5, 2008
   1995-12-22T09:05:02 = ·𐑛𐑭 22, 1995
  -0010-09-15T04:44:23 = ·𐑕𐑧 15, -10

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 6:30:30 𐑐𐑥 UTC
   1995-12-22T09:05:02 = 9:05:02 𐑨𐑥 UTC
  -0010-09-15T04:44:23 = 4:44:23 𐑨𐑥 UTC

=head3 Long

   2008-02-05T18:30:30 = 6:30:30 𐑐𐑥 UTC
   1995-12-22T09:05:02 = 9:05:02 𐑨𐑥 UTC
  -0010-09-15T04:44:23 = 4:44:23 𐑨𐑥 UTC

=head3 Medium

   2008-02-05T18:30:30 = 6:30:30 𐑐𐑥
   1995-12-22T09:05:02 = 9:05:02 𐑨𐑥
  -0010-09-15T04:44:23 = 4:44:23 𐑨𐑥

=head3 Short

   2008-02-05T18:30:30 = 6:30 𐑐𐑥
   1995-12-22T09:05:02 = 9:05 𐑨𐑥
  -0010-09-15T04:44:23 = 4:44 𐑨𐑥

=head3 Default

   2008-02-05T18:30:30 = 6:30:30 𐑐𐑥
   1995-12-22T09:05:02 = 9:05:02 𐑨𐑥
  -0010-09-15T04:44:23 = 4:44:23 𐑨𐑥

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = ·𐑑𐑵𐑟𐑛𐑱, ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰 5, 2008 6:30:30 𐑐𐑥 UTC
   1995-12-22T09:05:02 = ·𐑓𐑮𐑲𐑛𐑱, ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸 22, 1995 9:05:02 𐑨𐑥 UTC
  -0010-09-15T04:44:23 = ·𐑕𐑨𐑛𐑻𐑛𐑱, ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸 15, -10 4:44:23 𐑨𐑥 UTC

=head3 Long

   2008-02-05T18:30:30 = ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰 5, 2008 6:30:30 𐑐𐑥 UTC
   1995-12-22T09:05:02 = ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸 22, 1995 9:05:02 𐑨𐑥 UTC
  -0010-09-15T04:44:23 = ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸 15, -10 4:44:23 𐑨𐑥 UTC

=head3 Medium

   2008-02-05T18:30:30 = ·𐑓𐑧 5, 2008 6:30:30 𐑐𐑥
   1995-12-22T09:05:02 = ·𐑛𐑭 22, 1995 9:05:02 𐑨𐑥
  -0010-09-15T04:44:23 = ·𐑕𐑧 15, -10 4:44:23 𐑨𐑥

=head3 Short

   2008-02-05T18:30:30 = 2/5/08 6:30 𐑐𐑥
   1995-12-22T09:05:02 = 12/22/95 9:05 𐑨𐑥
  -0010-09-15T04:44:23 = 9/15/-10 4:44 𐑨𐑥

=head3 Default

   2008-02-05T18:30:30 = ·𐑓𐑧 5, 2008 6:30:30 𐑐𐑥
   1995-12-22T09:05:02 = ·𐑛𐑭 22, 1995 9:05:02 𐑨𐑥
  -0010-09-15T04:44:23 = ·𐑕𐑧 15, -10 4:44:23 𐑨𐑥

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 ·𐑑𐑵
   1995-12-22T09:05:02 = 22 ·𐑓𐑮
  -0010-09-15T04:44:23 = 15 ·𐑕𐑨

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 𐑐𐑥
   1995-12-22T09:05:02 = 9:05 𐑨𐑥
  -0010-09-15T04:44:23 = 4:44 𐑨𐑥

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 𐑐𐑥
   1995-12-22T09:05:02 = 9:05:02 𐑨𐑥
  -0010-09-15T04:44:23 = 4:44:23 𐑨𐑥

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (M/d)

   2008-02-05T18:30:30 = 2/5
   1995-12-22T09:05:02 = 12/22
  -0010-09-15T04:44:23 = 9/15

=head3 MEd (E, M/d)

   2008-02-05T18:30:30 = ·𐑑𐑵, 2/5
   1995-12-22T09:05:02 = ·𐑓𐑮, 12/22
  -0010-09-15T04:44:23 = ·𐑕𐑨, 9/15

=head3 MMM (LLL)

   2008-02-05T18:30:30 = ·𐑓𐑧
   1995-12-22T09:05:02 = ·𐑛𐑭
  -0010-09-15T04:44:23 = ·𐑕𐑧

=head3 MMMd (MMM d)

   2008-02-05T18:30:30 = ·𐑓𐑧 5
   1995-12-22T09:05:02 = ·𐑛𐑭 22
  -0010-09-15T04:44:23 = ·𐑕𐑧 15

=head3 MMMEd (E, MMM d)

   2008-02-05T18:30:30 = ·𐑑𐑵, ·𐑓𐑧 5
   1995-12-22T09:05:02 = ·𐑓𐑮, ·𐑛𐑭 22
  -0010-09-15T04:44:23 = ·𐑕𐑨, ·𐑕𐑧 15

=head3 MMMMd (MMMM d)

   2008-02-05T18:30:30 = ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰 5
   1995-12-22T09:05:02 = ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸 22
  -0010-09-15T04:44:23 = ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸 15

=head3 MMMMEd (E, MMMM d)

   2008-02-05T18:30:30 = ·𐑑𐑵, ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰 5
   1995-12-22T09:05:02 = ·𐑓𐑮, ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸 22
  -0010-09-15T04:44:23 = ·𐑕𐑨, ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸 15

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (M/yyyy)

   2008-02-05T18:30:30 = 2/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 9/-010

=head3 yMEd (EEE, M/d/yyyy)

   2008-02-05T18:30:30 = ·𐑑𐑵, 2/5/2008
   1995-12-22T09:05:02 = ·𐑓𐑮, 12/22/1995
  -0010-09-15T04:44:23 = ·𐑕𐑨, 9/15/-010

=head3 yMMM (MMM y)

   2008-02-05T18:30:30 = ·𐑓𐑧 2008
   1995-12-22T09:05:02 = ·𐑛𐑭 1995
  -0010-09-15T04:44:23 = ·𐑕𐑧 -10

=head3 yMMMEd (EEE, MMM d, y)

   2008-02-05T18:30:30 = ·𐑑𐑵, ·𐑓𐑧 5, 2008
   1995-12-22T09:05:02 = ·𐑓𐑮, ·𐑛𐑭 22, 1995
  -0010-09-15T04:44:23 = ·𐑕𐑨, ·𐑕𐑧 15, -10

=head3 yMMMM (MMMM y)

   2008-02-05T18:30:30 = ·𐑓𐑧𐑚𐑘𐑵𐑢𐑺𐑰 2008
   1995-12-22T09:05:02 = ·𐑛𐑭𐑕𐑧𐑥𐑚𐑸 1995
  -0010-09-15T04:44:23 = ·𐑕𐑧𐑐𐑑𐑧𐑥𐑚𐑸 -10

=head3 yQ (Q yyyy)

   2008-02-05T18:30:30 = 1 2008
   1995-12-22T09:05:02 = 4 1995
  -0010-09-15T04:44:23 = 3 -010

=head3 yQQQ (QQQ y)

   2008-02-05T18:30:30 = 𐑒1 2008
   1995-12-22T09:05:02 = 𐑒4 1995
  -0010-09-15T04:44:23 = 𐑒3 -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

No

=head3 Local first day of the week

·𐑥𐑭𐑙𐑛𐑱


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
