###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file uz_Arab.xml
# The source file version number was 1.38, generated on
# 2009/06/15 05:50:27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::uz_Arab;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::uz';

sub cldr_version { return "1\.7\.1" }

{
    my $date_format_full = "y\ نچی\ ییل\ d\ نچی\ MMMM\ EEEE\ کونی";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ نچی\ MMMM\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "d\ MMM\ y";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "yyyy\/M\/d";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "د\.", "س\.", "چ\.", "پ\.", "ج\.", "ش\.", "ی\." ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_format_abbreviated() }

{
    my $day_format_wide = [ "دوشنبه", "سه‌شنبه", "چهارشنبه", "پنجشنبه", "جمعه", "شنبه", "یکشنبه" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }


sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "ق\.م\.", "م\." ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "جنو", "فبر", "مار", "اپر", "مـی", "جون", "جول", "اگس", "سپت", "اکت", "نوم", "دسم" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_format_abbreviated() }

{
    my $month_format_wide = [ "جنوری", "فبروری", "مارچ", "اپریل", "می", "جون", "جولای", "اگست", "سپتمبر", "اکتوبر", "نومبر", "دسمبر" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }


sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $time_format_full = "H\:mm\:ss\ \(zzzz\)";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "H\:mm\:ss\ \(z\)";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "H\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "H\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_MMMMd = "d\ نچی\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_Md = "M\/d";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_available_formats =
        {
          "MMMMd" => "d\ نچی\ MMMM",
          "Md" => "M\/d"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::uz_Arab

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'uz_Arab' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Uzbek Arabic.

=head1 DATA

This locale inherits from the L<DateTime::Locale::uz> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  دوشنبه
  سه‌شنبه
  چهارشنبه
  پنجشنبه
  جمعه
  شنبه
  یکشنبه

=head3 Abbreviated (format)

  د.
  س.
  چ.
  پ.
  ج.
  ش.
  ی.

=head3 Narrow (format)

  د.
  س.
  چ.
  پ.
  ج.
  ش.
  ی.

=head3 Wide (stand-alone)

  دوشنبه
  سه‌شنبه
  چهارشنبه
  پنجشنبه
  جمعه
  شنبه
  یکشنبه

=head3 Abbreviated (stand-alone)

  د.
  س.
  چ.
  پ.
  ج.
  ش.
  ی.

=head3 Narrow (stand-alone)

  Д
  С
  Ч
  П
  Ж
  Ш
  Я

=head2 Months

=head3 Wide (format)

  جنوری
  فبروری
  مارچ
  اپریل
  می
  جون
  جولای
  اگست
  سپتمبر
  اکتوبر
  نومبر
  دسمبر

=head3 Abbreviated (format)

  جنو
  فبر
  مار
  اپر
  مـی
  جون
  جول
  اگس
  سپت
  اکت
  نوم
  دسم

=head3 Narrow (format)

  جنو
  فبر
  مار
  اپر
  مـی
  جون
  جول
  اگس
  سپت
  اکت
  نوم
  دسم

=head3 Wide (stand-alone)

  جنوری
  فبروری
  مارچ
  اپریل
  می
  جون
  جولای
  اگست
  سپتمبر
  اکتوبر
  نومبر
  دسمبر

=head3 Abbreviated (stand-alone)

  جنو
  فبر
  مار
  اپر
  مـی
  جون
  جول
  اگس
  سپت
  اکت
  نوم
  دسم

=head3 Narrow (stand-alone)

  Я
  Ф
  М
  А
  М
  И
  И
  А
  С
  О
  Н
  Д

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  ق.م.
  م.

=head3 Narrow

  ق.م.
  م.

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = 2008 نچی ییل 5 نچی فبروری سه‌شنبه کونی
   1995-12-22T09:05:02 = 1995 نچی ییل 22 نچی دسمبر جمعه کونی
  -0010-09-15T04:44:23 = -10 نچی ییل 15 نچی سپتمبر شنبه کونی

=head3 Long

   2008-02-05T18:30:30 = 5 نچی فبروری 2008
   1995-12-22T09:05:02 = 22 نچی دسمبر 1995
  -0010-09-15T04:44:23 = 15 نچی سپتمبر -10

=head3 Medium

   2008-02-05T18:30:30 = 5 فبر 2008
   1995-12-22T09:05:02 = 22 دسم 1995
  -0010-09-15T04:44:23 = 15 سپت -10

=head3 Short

   2008-02-05T18:30:30 = 2008/2/5
   1995-12-22T09:05:02 = 1995/12/22
  -0010-09-15T04:44:23 = -010/9/15

=head3 Default

   2008-02-05T18:30:30 = 5 فبر 2008
   1995-12-22T09:05:02 = 22 دسم 1995
  -0010-09-15T04:44:23 = 15 سپت -10

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 (UTC)
   1995-12-22T09:05:02 = 9:05:02 (UTC)
  -0010-09-15T04:44:23 = 4:44:23 (UTC)

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 (UTC)
   1995-12-22T09:05:02 = 9:05:02 (UTC)
  -0010-09-15T04:44:23 = 4:44:23 (UTC)

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = 2008 نچی ییل 5 نچی فبروری سه‌شنبه کونی 18:30:30 (UTC)
   1995-12-22T09:05:02 = 1995 نچی ییل 22 نچی دسمبر جمعه کونی 9:05:02 (UTC)
  -0010-09-15T04:44:23 = -10 نچی ییل 15 نچی سپتمبر شنبه کونی 4:44:23 (UTC)

=head3 Long

   2008-02-05T18:30:30 = 5 نچی فبروری 2008 18:30:30 (UTC)
   1995-12-22T09:05:02 = 22 نچی دسمبر 1995 9:05:02 (UTC)
  -0010-09-15T04:44:23 = 15 نچی سپتمبر -10 4:44:23 (UTC)

=head3 Medium

   2008-02-05T18:30:30 = 5 فبر 2008 18:30:30
   1995-12-22T09:05:02 = 22 دسم 1995 9:05:02
  -0010-09-15T04:44:23 = 15 سپت -10 4:44:23

=head3 Short

   2008-02-05T18:30:30 = 2008/2/5 18:30
   1995-12-22T09:05:02 = 1995/12/22 9:05
  -0010-09-15T04:44:23 = -010/9/15 4:44

=head3 Default

   2008-02-05T18:30:30 = 5 فبر 2008 18:30:30
   1995-12-22T09:05:02 = 22 دسم 1995 9:05:02
  -0010-09-15T04:44:23 = 15 سپت -10 4:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 س.
   1995-12-22T09:05:02 = 22 ج.
  -0010-09-15T04:44:23 = 15 ش.

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 PM
   1995-12-22T09:05:02 = 9:05 AM
  -0010-09-15T04:44:23 = 4:44 AM

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 PM
   1995-12-22T09:05:02 = 9:05:02 AM
  -0010-09-15T04:44:23 = 4:44:23 AM

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (M/d)

   2008-02-05T18:30:30 = 2/5
   1995-12-22T09:05:02 = 12/22
  -0010-09-15T04:44:23 = 9/15

=head3 MEd (E, M-d)

   2008-02-05T18:30:30 = س., 2-5
   1995-12-22T09:05:02 = ج., 12-22
  -0010-09-15T04:44:23 = ش., 9-15

=head3 MMM (LLL)

   2008-02-05T18:30:30 = فبر
   1995-12-22T09:05:02 = دسم
  -0010-09-15T04:44:23 = سپت

=head3 MMMd (MMM d)

   2008-02-05T18:30:30 = فبر 5
   1995-12-22T09:05:02 = دسم 22
  -0010-09-15T04:44:23 = سپت 15

=head3 MMMEd (E MMM d)

   2008-02-05T18:30:30 = س. فبر 5
   1995-12-22T09:05:02 = ج. دسم 22
  -0010-09-15T04:44:23 = ش. سپت 15

=head3 MMMMd (d نچی MMMM)

   2008-02-05T18:30:30 = 5 نچی فبروری
   1995-12-22T09:05:02 = 22 نچی دسمبر
  -0010-09-15T04:44:23 = 15 نچی سپتمبر

=head3 MMMMEd (E MMMM d)

   2008-02-05T18:30:30 = س. فبروری 5
   1995-12-22T09:05:02 = ج. دسمبر 22
  -0010-09-15T04:44:23 = ش. سپتمبر 15

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (y-M)

   2008-02-05T18:30:30 = 2008-2
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -10-9

=head3 yMEd (EEE, y-M-d)

   2008-02-05T18:30:30 = س., 2008-2-5
   1995-12-22T09:05:02 = ج., 1995-12-22
  -0010-09-15T04:44:23 = ش., -10-9-15

=head3 yMMM (y MMM)

   2008-02-05T18:30:30 = 2008 فبر
   1995-12-22T09:05:02 = 1995 دسم
  -0010-09-15T04:44:23 = -10 سپت

=head3 yMMMEd (EEE, y MMM d)

   2008-02-05T18:30:30 = س., 2008 فبر 5
   1995-12-22T09:05:02 = ج., 1995 دسم 22
  -0010-09-15T04:44:23 = ش., -10 سپت 15

=head3 yMMMM (y MMMM)

   2008-02-05T18:30:30 = 2008 فبروری
   1995-12-22T09:05:02 = 1995 دسمبر
  -0010-09-15T04:44:23 = -10 سپتمبر

=head3 yQ (y Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -10 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 Q1
   1995-12-22T09:05:02 = 1995 Q4
  -0010-09-15T04:44:23 = -10 Q3

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyyM (yyyy/M)

   2008-02-05T18:30:30 = 2008/2
   1995-12-22T09:05:02 = 1995/12
  -0010-09-15T04:44:23 = -010/9

=head3 yyyyMMMM (MMMM y)

   2008-02-05T18:30:30 = فبروری 2008
   1995-12-22T09:05:02 = دسمبر 1995
  -0010-09-15T04:44:23 = سپتمبر -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

دوشنبه


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
