###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file yo.xml
# The source file version number was 1.37, generated on
# 2009/06/15 03:46:25.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::yo;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "àárọ̀", "ọ̀sán" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $day_format_abbreviated = [ "Ajé", "Ìsẹ́gun", "Ọjọ́rú", "Àṣẹ̀ṣẹ̀dáiyé", "Ẹtì", "Àbámẹ́ta", "Àìkú" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_format_abbreviated() }

{
    my $day_format_wide = [ "Ọjọ́\ Ajé", "Ọjọ́\ Ìsẹ́gun", "Ọjọ́rú", "Ọjọ́\ Àṣẹ̀ṣẹ̀dáiyé", "Ọjọ́\ Ẹtì", "Ọjọ́\ Àbámẹ́ta", "Ọjọ́\ Àìkú" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }


sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "SK", "LK" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "Saju\ Kristi", "Lehin\ Kristi" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "Ṣẹ́rẹ́", "Èrèlè", "Ẹrẹ̀nà", "Ìgbé", "Ẹ̀bibi", "Òkúdu", "Agẹmọ", "Ògún", "Owewe", "Ọ̀wàrà", "Bélú", "Ọ̀pẹ̀" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_format_abbreviated() }

{
    my $month_format_wide = [ "Oṣù\ Ṣẹ́rẹ́", "Oṣù\ Èrèlè", "Oṣù\ Ẹrẹ̀nà", "Oṣù\ Ìgbé", "Oṣù\ Ẹ̀bibi", "Oṣù\ Òkúdu", "Oṣù\ Agẹmọ", "Oṣù\ Ògún", "Oṣù\ Owewe", "Oṣù\ Ọ̀wàrà", "Oṣù\ Bélú", "Oṣù\ Ọ̀pẹ̀" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }


sub month_stand_alone_wide { $_[0]->month_format_wide() }

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::yo

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'yo' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Yoruba.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Ọjọ́ Ajé
  Ọjọ́ Ìsẹ́gun
  Ọjọ́rú
  Ọjọ́ Àṣẹ̀ṣẹ̀dáiyé
  Ọjọ́ Ẹtì
  Ọjọ́ Àbámẹ́ta
  Ọjọ́ Àìkú

=head3 Abbreviated (format)

  Ajé
  Ìsẹ́gun
  Ọjọ́rú
  Àṣẹ̀ṣẹ̀dáiyé
  Ẹtì
  Àbámẹ́ta
  Àìkú

=head3 Narrow (format)

  Ajé
  Ìsẹ́gun
  Ọjọ́rú
  Àṣẹ̀ṣẹ̀dáiyé
  Ẹtì
  Àbámẹ́ta
  Àìkú

=head3 Wide (stand-alone)

  Ọjọ́ Ajé
  Ọjọ́ Ìsẹ́gun
  Ọjọ́rú
  Ọjọ́ Àṣẹ̀ṣẹ̀dáiyé
  Ọjọ́ Ẹtì
  Ọjọ́ Àbámẹ́ta
  Ọjọ́ Àìkú

=head3 Abbreviated (stand-alone)

  Ajé
  Ìsẹ́gun
  Ọjọ́rú
  Àṣẹ̀ṣẹ̀dáiyé
  Ẹtì
  Àbámẹ́ta
  Àìkú

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  Oṣù Ṣẹ́rẹ́
  Oṣù Èrèlè
  Oṣù Ẹrẹ̀nà
  Oṣù Ìgbé
  Oṣù Ẹ̀bibi
  Oṣù Òkúdu
  Oṣù Agẹmọ
  Oṣù Ògún
  Oṣù Owewe
  Oṣù Ọ̀wàrà
  Oṣù Bélú
  Oṣù Ọ̀pẹ̀

=head3 Abbreviated (format)

  Ṣẹ́rẹ́
  Èrèlè
  Ẹrẹ̀nà
  Ìgbé
  Ẹ̀bibi
  Òkúdu
  Agẹmọ
  Ògún
  Owewe
  Ọ̀wàrà
  Bélú
  Ọ̀pẹ̀

=head3 Narrow (format)

  Ṣẹ́rẹ́
  Èrèlè
  Ẹrẹ̀nà
  Ìgbé
  Ẹ̀bibi
  Òkúdu
  Agẹmọ
  Ògún
  Owewe
  Ọ̀wàrà
  Bélú
  Ọ̀pẹ̀

=head3 Wide (stand-alone)

  Oṣù Ṣẹ́rẹ́
  Oṣù Èrèlè
  Oṣù Ẹrẹ̀nà
  Oṣù Ìgbé
  Oṣù Ẹ̀bibi
  Oṣù Òkúdu
  Oṣù Agẹmọ
  Oṣù Ògún
  Oṣù Owewe
  Oṣù Ọ̀wàrà
  Oṣù Bélú
  Oṣù Ọ̀pẹ̀

=head3 Abbreviated (stand-alone)

  Ṣẹ́rẹ́
  Èrèlè
  Ẹrẹ̀nà
  Ìgbé
  Ẹ̀bibi
  Òkúdu
  Agẹmọ
  Ògún
  Owewe
  Ọ̀wàrà
  Bélú
  Ọ̀pẹ̀

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  Saju Kristi
  Lehin Kristi

=head3 Abbreviated

  SK
  LK

=head3 Narrow

  SK
  LK

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = Ọjọ́ Ìsẹ́gun, 2008 Oṣù Èrèlè 05
   1995-12-22T09:05:02 = Ọjọ́ Ẹtì, 1995 Oṣù Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = Ọjọ́ Àbámẹ́ta, -10 Oṣù Owewe 15

=head3 Long

   2008-02-05T18:30:30 = 2008 Oṣù Èrèlè 5
   1995-12-22T09:05:02 = 1995 Oṣù Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = -10 Oṣù Owewe 15

=head3 Medium

   2008-02-05T18:30:30 = 2008 Èrèlè 5
   1995-12-22T09:05:02 = 1995 Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = -10 Owewe 15

=head3 Short

   2008-02-05T18:30:30 = 2008-02-05
   1995-12-22T09:05:02 = 1995-12-22
  -0010-09-15T04:44:23 = -010-09-15

=head3 Default

   2008-02-05T18:30:30 = 2008 Èrèlè 5
   1995-12-22T09:05:02 = 1995 Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = -10 Owewe 15

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = Ọjọ́ Ìsẹ́gun, 2008 Oṣù Èrèlè 05 18:30:30 UTC
   1995-12-22T09:05:02 = Ọjọ́ Ẹtì, 1995 Oṣù Ọ̀pẹ̀ 22 09:05:02 UTC
  -0010-09-15T04:44:23 = Ọjọ́ Àbámẹ́ta, -10 Oṣù Owewe 15 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 2008 Oṣù Èrèlè 5 18:30:30 UTC
   1995-12-22T09:05:02 = 1995 Oṣù Ọ̀pẹ̀ 22 09:05:02 UTC
  -0010-09-15T04:44:23 = -10 Oṣù Owewe 15 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 2008 Èrèlè 5 18:30:30
   1995-12-22T09:05:02 = 1995 Ọ̀pẹ̀ 22 09:05:02
  -0010-09-15T04:44:23 = -10 Owewe 15 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 2008-02-05 18:30
   1995-12-22T09:05:02 = 1995-12-22 09:05
  -0010-09-15T04:44:23 = -010-09-15 04:44

=head3 Default

   2008-02-05T18:30:30 = 2008 Èrèlè 5 18:30:30
   1995-12-22T09:05:02 = 1995 Ọ̀pẹ̀ 22 09:05:02
  -0010-09-15T04:44:23 = -10 Owewe 15 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 Ìsẹ́gun
   1995-12-22T09:05:02 = 22 Ẹtì
  -0010-09-15T04:44:23 = 15 Àbámẹ́ta

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 ọ̀sán
   1995-12-22T09:05:02 = 9:05 àárọ̀
  -0010-09-15T04:44:23 = 4:44 àárọ̀

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 ọ̀sán
   1995-12-22T09:05:02 = 9:05:02 àárọ̀
  -0010-09-15T04:44:23 = 4:44:23 àárọ̀

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (M-d)

   2008-02-05T18:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-09-15T04:44:23 = 9-15

=head3 MEd (E, M-d)

   2008-02-05T18:30:30 = Ìsẹ́gun, 2-5
   1995-12-22T09:05:02 = Ẹtì, 12-22
  -0010-09-15T04:44:23 = Àbámẹ́ta, 9-15

=head3 MMM (LLL)

   2008-02-05T18:30:30 = Èrèlè
   1995-12-22T09:05:02 = Ọ̀pẹ̀
  -0010-09-15T04:44:23 = Owewe

=head3 MMMd (MMM d)

   2008-02-05T18:30:30 = Èrèlè 5
   1995-12-22T09:05:02 = Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = Owewe 15

=head3 MMMEd (E MMM d)

   2008-02-05T18:30:30 = Ìsẹ́gun Èrèlè 5
   1995-12-22T09:05:02 = Ẹtì Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = Àbámẹ́ta Owewe 15

=head3 MMMMd (MMMM d)

   2008-02-05T18:30:30 = Oṣù Èrèlè 5
   1995-12-22T09:05:02 = Oṣù Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = Oṣù Owewe 15

=head3 MMMMEd (E MMMM d)

   2008-02-05T18:30:30 = Ìsẹ́gun Oṣù Èrèlè 5
   1995-12-22T09:05:02 = Ẹtì Oṣù Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = Àbámẹ́ta Oṣù Owewe 15

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (y-M)

   2008-02-05T18:30:30 = 2008-2
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -10-9

=head3 yMEd (EEE, y-M-d)

   2008-02-05T18:30:30 = Ìsẹ́gun, 2008-2-5
   1995-12-22T09:05:02 = Ẹtì, 1995-12-22
  -0010-09-15T04:44:23 = Àbámẹ́ta, -10-9-15

=head3 yMMM (y MMM)

   2008-02-05T18:30:30 = 2008 Èrèlè
   1995-12-22T09:05:02 = 1995 Ọ̀pẹ̀
  -0010-09-15T04:44:23 = -10 Owewe

=head3 yMMMEd (EEE, y MMM d)

   2008-02-05T18:30:30 = Ìsẹ́gun, 2008 Èrèlè 5
   1995-12-22T09:05:02 = Ẹtì, 1995 Ọ̀pẹ̀ 22
  -0010-09-15T04:44:23 = Àbámẹ́ta, -10 Owewe 15

=head3 yMMMM (y MMMM)

   2008-02-05T18:30:30 = 2008 Oṣù Èrèlè
   1995-12-22T09:05:02 = 1995 Oṣù Ọ̀pẹ̀
  -0010-09-15T04:44:23 = -10 Oṣù Owewe

=head3 yQ (y Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -10 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 Q1
   1995-12-22T09:05:02 = 1995 Q4
  -0010-09-15T04:44:23 = -10 Q3

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Ọjọ́ Ajé


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
