# This file is auto-generated by the Perl DateTime Suite time zone
# code generator (0.07) This code generator comes with the
# DateTime::TimeZone module distribution in the tools/ directory

#
# Generated from /tmp/ggU06B80sE/africa.  Olson data version 2013c
#
# Do not edit this file directly.
#
package DateTime::TimeZone::Africa::Bamako;
{
  $DateTime::TimeZone::Africa::Bamako::VERSION = '1.59';
}

use strict;

use Class::Singleton 1.03;
use DateTime::TimeZone;
use DateTime::TimeZone::OlsonDB;

@DateTime::TimeZone::Africa::Bamako::ISA = ( 'Class::Singleton', 'DateTime::TimeZone' );

my $spans =
[
    [
DateTime::TimeZone::NEG_INFINITY, #    utc_start
60305301120, #      utc_end 1912-01-01 00:32:00 (Mon)
DateTime::TimeZone::NEG_INFINITY, #  local_start
60305299200, #    local_end 1912-01-01 00:00:00 (Mon)
-1920,
0,
'LMT',
    ],
    [
60305301120, #    utc_start 1912-01-01 00:32:00 (Mon)
61004448000, #      utc_end 1934-02-26 00:00:00 (Mon)
60305301120, #  local_start 1912-01-01 00:32:00 (Mon)
61004448000, #    local_end 1934-02-26 00:00:00 (Mon)
0,
0,
'GMT',
    ],
    [
61004448000, #    utc_start 1934-02-26 00:00:00 (Mon)
61834842000, #      utc_end 1960-06-20 01:00:00 (Mon)
61004444400, #  local_start 1934-02-25 23:00:00 (Sun)
61834838400, #    local_end 1960-06-20 00:00:00 (Mon)
-3600,
0,
'WAT',
    ],
    [
61834842000, #    utc_start 1960-06-20 01:00:00 (Mon)
DateTime::TimeZone::INFINITY, #      utc_end
61834842000, #  local_start 1960-06-20 01:00:00 (Mon)
DateTime::TimeZone::INFINITY, #    local_end
0,
0,
'GMT',
    ],
];

sub olson_version { '2013c' }

sub has_dst_changes { 0 }

sub _max_year { 2023 }

sub _new_instance
{
    return shift->_init( @_, spans => $spans );
}



1;

