# This file is auto-generated by the Perl DateTime Suite time zone
# code generator (0.07) This code generator comes with the
# DateTime::TimeZone module distribution in the tools/ directory

#
# Generated from /tmp/ggU06B80sE/africa.  Olson data version 2013c
#
# Do not edit this file directly.
#
package DateTime::TimeZone::Africa::Dar_es_Salaam;
{
  $DateTime::TimeZone::Africa::Dar_es_Salaam::VERSION = '1.59';
}

use strict;

use Class::Singleton 1.03;
use DateTime::TimeZone;
use DateTime::TimeZone::OlsonDB;

@DateTime::TimeZone::Africa::Dar_es_Salaam::ISA = ( 'Class::Singleton', 'DateTime::TimeZone' );

my $spans =
[
    [
DateTime::TimeZone::NEG_INFINITY, #    utc_start
60904905772, #      utc_end 1930-12-31 21:22:52 (Wed)
DateTime::TimeZone::NEG_INFINITY, #  local_start
60904915200, #    local_end 1931-01-01 00:00:00 (Thu)
9428,
0,
'LMT',
    ],
    [
60904905772, #    utc_start 1930-12-31 21:22:52 (Wed)
61441362000, #      utc_end 1947-12-31 21:00:00 (Wed)
60904916572, #  local_start 1931-01-01 00:22:52 (Thu)
61441372800, #    local_end 1948-01-01 00:00:00 (Thu)
10800,
0,
'EAT',
    ],
    [
61441362000, #    utc_start 1947-12-31 21:00:00 (Wed)
61851676500, #      utc_end 1960-12-31 21:15:00 (Sat)
61441371900, #  local_start 1947-12-31 23:45:00 (Wed)
61851686400, #    local_end 1961-01-01 00:00:00 (Sun)
9900,
0,
'BEAUT',
    ],
    [
61851676500, #    utc_start 1960-12-31 21:15:00 (Sat)
DateTime::TimeZone::INFINITY, #      utc_end
61851687300, #  local_start 1961-01-01 00:15:00 (Sun)
DateTime::TimeZone::INFINITY, #    local_end
10800,
0,
'EAT',
    ],
];

sub olson_version { '2013c' }

sub has_dst_changes { 0 }

sub _max_year { 2023 }

sub _new_instance
{
    return shift->_init( @_, spans => $spans );
}



1;

