###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file ha.xml
# The source file version number was 1.38, generated on
# 2009/06/15 03:46:24.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ha;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "AM", "PM" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ d\ MMMM\,\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ MMMM\,\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "d\ MMM\,\ y";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "d\/M\/yy";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "Lit", "Tal", "Lar", "Alh", "Jum", "Asa", "Lah" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "Litini", "Talata", "Laraba", "Alhamis", "Jumma\'a", "Asabar", "Lahadi" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "L", "T", "L", "A", "J", "A", "L" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "GM", "M" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "Gabanin\ Miladi", "Miladi" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "Jan", "Fab", "Mar", "Afr", "May", "Yun", "Yul", "Aug", "Sat", "Okt", "Nuw", "Dis" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "Janairu", "Fabrairu", "Maris", "Afrilu", "Mayu", "Yuni", "Yuli", "Augusta", "Satumba", "Oktoba", "Nuwamba", "Disamba" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "J", "F", "M", "A", "M", "Y", "Y", "A", "S", "O", "N", "D" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "Q1", "Q2", "Q3", "Q4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "Q1", "Q2", "Q3", "Q4" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "HH\:mm\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_Hm = "H\:mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "E\,\ d\-M";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "E\ d\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\ d\ MMMM";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_Md = "M\-d";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_ms = "mm\:ss";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yMEd = "EEE\,\ d\/M\/yyyy";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMMEd = "EEE\,\ d\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_available_formats =
        {
          "Hm" => "H\:mm",
          "M" => "L",
          "MEd" => "E\,\ d\-M",
          "MMM" => "LLL",
          "MMMEd" => "E\ d\ MMM",
          "MMMMEd" => "E\ d\ MMMM",
          "MMMMd" => "d\ MMMM",
          "MMMd" => "d\ MMM",
          "Md" => "M\-d",
          "d" => "d",
          "ms" => "mm\:ss",
          "y" => "y",
          "yMEd" => "EEE\,\ d\/M\/yyyy",
          "yMMMEd" => "EEE\,\ d\ MMM\ y",
          "yyQ" => "Q\ yy"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::ha

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'ha' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Hausa.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Litini
  Talata
  Laraba
  Alhamis
  Jumma'a
  Asabar
  Lahadi

=head3 Abbreviated (format)

  Lit
  Tal
  Lar
  Alh
  Jum
  Asa
  Lah

=head3 Narrow (format)

  L
  T
  L
  A
  J
  A
  L

=head3 Wide (stand-alone)

  Litini
  Talata
  Laraba
  Alhamis
  Jumma'a
  Asabar
  Lahadi

=head3 Abbreviated (stand-alone)

  Lit
  Tal
  Lar
  Alh
  Jum
  Asa
  Lah

=head3 Narrow (stand-alone)

  L
  T
  L
  A
  J
  A
  L

=head2 Months

=head3 Wide (format)

  Janairu
  Fabrairu
  Maris
  Afrilu
  Mayu
  Yuni
  Yuli
  Augusta
  Satumba
  Oktoba
  Nuwamba
  Disamba

=head3 Abbreviated (format)

  Jan
  Fab
  Mar
  Afr
  May
  Yun
  Yul
  Aug
  Sat
  Okt
  Nuw
  Dis

=head3 Narrow (format)

  J
  F
  M
  A
  M
  Y
  Y
  A
  S
  O
  N
  D

=head3 Wide (stand-alone)

  Janairu
  Fabrairu
  Maris
  Afrilu
  Mayu
  Yuni
  Yuli
  Augusta
  Satumba
  Oktoba
  Nuwamba
  Disamba

=head3 Abbreviated (stand-alone)

  Jan
  Fab
  Mar
  Afr
  May
  Yun
  Yul
  Aug
  Sat
  Okt
  Nuw
  Dis

=head3 Narrow (stand-alone)

  J
  F
  M
  A
  M
  Y
  Y
  A
  S
  O
  N
  D

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  Gabanin Miladi
  Miladi

=head3 Abbreviated

  GM
  M

=head3 Narrow

  GM
  M

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = Talata, 5 Fabrairu, 2008
   1995-12-22T09:05:02 = Jumma'a, 22 Disamba, 1995
  -0010-09-15T04:44:23 = Asabar, 15 Satumba, -10

=head3 Long

   2008-02-05T18:30:30 = 5 Fabrairu, 2008
   1995-12-22T09:05:02 = 22 Disamba, 1995
  -0010-09-15T04:44:23 = 15 Satumba, -10

=head3 Medium

   2008-02-05T18:30:30 = 5 Fab, 2008
   1995-12-22T09:05:02 = 22 Dis, 1995
  -0010-09-15T04:44:23 = 15 Sat, -10

=head3 Short

   2008-02-05T18:30:30 = 5/2/08
   1995-12-22T09:05:02 = 22/12/95
  -0010-09-15T04:44:23 = 15/9/-10

=head3 Default

   2008-02-05T18:30:30 = 5 Fab, 2008
   1995-12-22T09:05:02 = 22 Dis, 1995
  -0010-09-15T04:44:23 = 15 Sat, -10

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = Talata, 5 Fabrairu, 2008 18:30:30 UTC
   1995-12-22T09:05:02 = Jumma'a, 22 Disamba, 1995 09:05:02 UTC
  -0010-09-15T04:44:23 = Asabar, 15 Satumba, -10 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 5 Fabrairu, 2008 18:30:30 UTC
   1995-12-22T09:05:02 = 22 Disamba, 1995 09:05:02 UTC
  -0010-09-15T04:44:23 = 15 Satumba, -10 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 5 Fab, 2008 18:30:30
   1995-12-22T09:05:02 = 22 Dis, 1995 09:05:02
  -0010-09-15T04:44:23 = 15 Sat, -10 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 5/2/08 18:30
   1995-12-22T09:05:02 = 22/12/95 09:05
  -0010-09-15T04:44:23 = 15/9/-10 04:44

=head3 Default

   2008-02-05T18:30:30 = 5 Fab, 2008 18:30:30
   1995-12-22T09:05:02 = 22 Dis, 1995 09:05:02
  -0010-09-15T04:44:23 = 15 Sat, -10 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 Tal
   1995-12-22T09:05:02 = 22 Jum
  -0010-09-15T04:44:23 = 15 Asa

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 PM
   1995-12-22T09:05:02 = 9:05 AM
  -0010-09-15T04:44:23 = 4:44 AM

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 PM
   1995-12-22T09:05:02 = 9:05:02 AM
  -0010-09-15T04:44:23 = 4:44:23 AM

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (M-d)

   2008-02-05T18:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-09-15T04:44:23 = 9-15

=head3 MEd (E, d-M)

   2008-02-05T18:30:30 = Tal, 5-2
   1995-12-22T09:05:02 = Jum, 22-12
  -0010-09-15T04:44:23 = Asa, 15-9

=head3 MMM (LLL)

   2008-02-05T18:30:30 = Fab
   1995-12-22T09:05:02 = Dis
  -0010-09-15T04:44:23 = Sat

=head3 MMMd (d MMM)

   2008-02-05T18:30:30 = 5 Fab
   1995-12-22T09:05:02 = 22 Dis
  -0010-09-15T04:44:23 = 15 Sat

=head3 MMMEd (E d MMM)

   2008-02-05T18:30:30 = Tal 5 Fab
   1995-12-22T09:05:02 = Jum 22 Dis
  -0010-09-15T04:44:23 = Asa 15 Sat

=head3 MMMMd (d MMMM)

   2008-02-05T18:30:30 = 5 Fabrairu
   1995-12-22T09:05:02 = 22 Disamba
  -0010-09-15T04:44:23 = 15 Satumba

=head3 MMMMEd (E d MMMM)

   2008-02-05T18:30:30 = Tal 5 Fabrairu
   1995-12-22T09:05:02 = Jum 22 Disamba
  -0010-09-15T04:44:23 = Asa 15 Satumba

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (y-M)

   2008-02-05T18:30:30 = 2008-2
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -10-9

=head3 yMEd (EEE, d/M/yyyy)

   2008-02-05T18:30:30 = Tal, 5/2/2008
   1995-12-22T09:05:02 = Jum, 22/12/1995
  -0010-09-15T04:44:23 = Asa, 15/9/-010

=head3 yMMM (y MMM)

   2008-02-05T18:30:30 = 2008 Fab
   1995-12-22T09:05:02 = 1995 Dis
  -0010-09-15T04:44:23 = -10 Sat

=head3 yMMMEd (EEE, d MMM y)

   2008-02-05T18:30:30 = Tal, 5 Fab 2008
   1995-12-22T09:05:02 = Jum, 22 Dis 1995
  -0010-09-15T04:44:23 = Asa, 15 Sat -10

=head3 yMMMM (y MMMM)

   2008-02-05T18:30:30 = 2008 Fabrairu
   1995-12-22T09:05:02 = 1995 Disamba
  -0010-09-15T04:44:23 = -10 Satumba

=head3 yQ (y Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -10 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 Q1
   1995-12-22T09:05:02 = 1995 Q4
  -0010-09-15T04:44:23 = -10 Q3

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Litini


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
