###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file pt.xml
# The source file version number was 1.126, generated on
# 2009/06/15 03:46:24.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::pt;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "AM", "PM" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ d\ \'de\'\ MMMM\ \'de\'\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "d\ \'de\'\ MMMM\ \'de\'\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "dd\/MM\/yyyy";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "dd\/MM\/yy";
    sub date_format_short { return $date_format_short }
}

{
    my $datetime_format = "\{1\}\ \{0\}";
    sub datetime_format { return $datetime_format }
}

{
    my $day_format_abbreviated = [ "seg", "ter", "qua", "qui", "sex", "sáb", "dom" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "segunda\-feira", "terça\-feira", "quarta\-feira", "quinta\-feira", "sexta\-feira", "sábado", "domingo" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "S", "T", "Q", "Q", "S", "S", "D" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "a\.C\.", "d\.C\." ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $era_wide = [ "Antes\ de\ Cristo", "Ano\ do\ Senhor" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "jan", "fev", "mar", "abr", "mai", "jun", "jul", "ago", "set", "out", "nov", "dez" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "janeiro", "fevereiro", "março", "abril", "maio", "junho", "julho", "agosto", "setembro", "outubro", "novembro", "dezembro" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "J", "F", "M", "A", "M", "J", "J", "A", "S", "O", "N", "D" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "T1", "T2", "T3", "T4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "1º\ trimestre", "2º\ trimestre", "3º\ trimestre", "4º\ trimestre" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "HH\'h\'mm\'min\'ss\'s\'\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\'h\'mm\'min\'ss\'s\'\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_EEEd = "EEE\,\ d";
    sub _format_for_EEEd { return $_format_for_EEEd }
}

{
    my $_format_for_HHmm = "HH\'h\'mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "H\'h\'mm\'min\'ss\'s\'";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_Hm = "H\'h\'mm";
    sub _format_for_Hm { return $_format_for_Hm }
}

{
    my $_format_for_M = "L";
    sub _format_for_M { return $_format_for_M }
}

{
    my $_format_for_MEd = "EEE\,\ dd\/MM";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMM = "LLL";
    sub _format_for_MMM { return $_format_for_MMM }
}

{
    my $_format_for_MMMEd = "EEE\,\ d\ \'de\'\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "EEE\,\ d\ \'de\'\ MMMM";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ \'de\'\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ \'de\'\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_MMdd = "dd\/MM";
    sub _format_for_MMdd { return $_format_for_MMdd }
}

{
    my $_format_for_Md = "d\/M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_d = "d";
    sub _format_for_d { return $_format_for_d }
}

{
    my $_format_for_mmss = "mm\'min\'ss\'s\'";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_ms = "mm\'min\'ss\'s\'";
    sub _format_for_ms { return $_format_for_ms }
}

{
    my $_format_for_y = "y";
    sub _format_for_y { return $_format_for_y }
}

{
    my $_format_for_yM = "MM\/yyyy";
    sub _format_for_yM { return $_format_for_yM }
}

{
    my $_format_for_yMEd = "EEE\,\ dd\/MM\/yyyy";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "MMM\ \'de\'\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\,\ d\ \'de\'\ MMM\ \'de\'\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "MMMM\ \'de\'\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "yyyy\ Q";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "y\ QQQ";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyMM = "MM\/yy";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "MMM\ \'de\'\ yy";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyMMMEEEd = "EEE\,\ d\ \'de\'\ MMM\ \'de\'\ yy";
    sub _format_for_yyMMMEEEd { return $_format_for_yyMMMEEEd }
}

{
    my $_format_for_yyMMMd = "d\ \'de\'\ MMM\ \'de\'\ yy";
    sub _format_for_yyMMMd { return $_format_for_yyMMMd }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyMM = "MM\/yyyy";
    sub _format_for_yyyyMM { return $_format_for_yyyyMM }
}

{
    my $_format_for_yyyyMMM = "MMM\ \'de\'\ y";
    sub _format_for_yyyyMMM { return $_format_for_yyyyMMM }
}

{
    my $_available_formats =
        {
          "EEEd" => "EEE\,\ d",
          "HHmm" => "HH\'h\'mm",
          "HHmmss" => "H\'h\'mm\'min\'ss\'s\'",
          "Hm" => "H\'h\'mm",
          "M" => "L",
          "MEd" => "EEE\,\ dd\/MM",
          "MMM" => "LLL",
          "MMMEd" => "EEE\,\ d\ \'de\'\ MMM",
          "MMMMEd" => "EEE\,\ d\ \'de\'\ MMMM",
          "MMMMd" => "d\ \'de\'\ MMMM",
          "MMMd" => "d\ \'de\'\ MMM",
          "MMdd" => "dd\/MM",
          "Md" => "d\/M",
          "d" => "d",
          "mmss" => "mm\'min\'ss\'s\'",
          "ms" => "mm\'min\'ss\'s\'",
          "y" => "y",
          "yM" => "MM\/yyyy",
          "yMEd" => "EEE\,\ dd\/MM\/yyyy",
          "yMMM" => "MMM\ \'de\'\ y",
          "yMMMEd" => "EEE\,\ d\ \'de\'\ MMM\ \'de\'\ y",
          "yMMMM" => "MMMM\ \'de\'\ y",
          "yQ" => "yyyy\ Q",
          "yQQQ" => "y\ QQQ",
          "yyMM" => "MM\/yy",
          "yyMMM" => "MMM\ \'de\'\ yy",
          "yyMMMEEEd" => "EEE\,\ d\ \'de\'\ MMM\ \'de\'\ yy",
          "yyMMMd" => "d\ \'de\'\ MMM\ \'de\'\ yy",
          "yyQ" => "Q\ yy",
          "yyyyMM" => "MM\/yyyy",
          "yyyyMMM" => "MMM\ \'de\'\ y"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::pt

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'pt' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Portuguese.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  segunda-feira
  terça-feira
  quarta-feira
  quinta-feira
  sexta-feira
  sábado
  domingo

=head3 Abbreviated (format)

  seg
  ter
  qua
  qui
  sex
  sáb
  dom

=head3 Narrow (format)

  S
  T
  Q
  Q
  S
  S
  D

=head3 Wide (stand-alone)

  segunda-feira
  terça-feira
  quarta-feira
  quinta-feira
  sexta-feira
  sábado
  domingo

=head3 Abbreviated (stand-alone)

  seg
  ter
  qua
  qui
  sex
  sáb
  dom

=head3 Narrow (stand-alone)

  S
  T
  Q
  Q
  S
  S
  D

=head2 Months

=head3 Wide (format)

  janeiro
  fevereiro
  março
  abril
  maio
  junho
  julho
  agosto
  setembro
  outubro
  novembro
  dezembro

=head3 Abbreviated (format)

  jan
  fev
  mar
  abr
  mai
  jun
  jul
  ago
  set
  out
  nov
  dez

=head3 Narrow (format)

  J
  F
  M
  A
  M
  J
  J
  A
  S
  O
  N
  D

=head3 Wide (stand-alone)

  janeiro
  fevereiro
  março
  abril
  maio
  junho
  julho
  agosto
  setembro
  outubro
  novembro
  dezembro

=head3 Abbreviated (stand-alone)

  jan
  fev
  mar
  abr
  mai
  jun
  jul
  ago
  set
  out
  nov
  dez

=head3 Narrow (stand-alone)

  J
  F
  M
  A
  M
  J
  J
  A
  S
  O
  N
  D

=head2 Quarters

=head3 Wide (format)

  1º trimestre
  2º trimestre
  3º trimestre
  4º trimestre

=head3 Abbreviated (format)

  T1
  T2
  T3
  T4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1º trimestre
  2º trimestre
  3º trimestre
  4º trimestre

=head3 Abbreviated (stand-alone)

  T1
  T2
  T3
  T4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  Antes de Cristo
  Ano do Senhor

=head3 Abbreviated

  a.C.
  d.C.

=head3 Narrow

  a.C.
  d.C.

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = terça-feira, 5 de fevereiro de 2008
   1995-12-22T09:05:02 = sexta-feira, 22 de dezembro de 1995
  -0010-09-15T04:44:23 = sábado, 15 de setembro de -10

=head3 Long

   2008-02-05T18:30:30 = 5 de fevereiro de 2008
   1995-12-22T09:05:02 = 22 de dezembro de 1995
  -0010-09-15T04:44:23 = 15 de setembro de -10

=head3 Medium

   2008-02-05T18:30:30 = 05/02/2008
   1995-12-22T09:05:02 = 22/12/1995
  -0010-09-15T04:44:23 = 15/09/-010

=head3 Short

   2008-02-05T18:30:30 = 05/02/08
   1995-12-22T09:05:02 = 22/12/95
  -0010-09-15T04:44:23 = 15/09/-10

=head3 Default

   2008-02-05T18:30:30 = 05/02/2008
   1995-12-22T09:05:02 = 22/12/1995
  -0010-09-15T04:44:23 = 15/09/-010

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18h30min30s UTC
   1995-12-22T09:05:02 = 09h05min02s UTC
  -0010-09-15T04:44:23 = 04h44min23s UTC

=head3 Long

   2008-02-05T18:30:30 = 18h30min30s UTC
   1995-12-22T09:05:02 = 09h05min02s UTC
  -0010-09-15T04:44:23 = 04h44min23s UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = terça-feira, 5 de fevereiro de 2008 18h30min30s UTC
   1995-12-22T09:05:02 = sexta-feira, 22 de dezembro de 1995 09h05min02s UTC
  -0010-09-15T04:44:23 = sábado, 15 de setembro de -10 04h44min23s UTC

=head3 Long

   2008-02-05T18:30:30 = 5 de fevereiro de 2008 18h30min30s UTC
   1995-12-22T09:05:02 = 22 de dezembro de 1995 09h05min02s UTC
  -0010-09-15T04:44:23 = 15 de setembro de -10 04h44min23s UTC

=head3 Medium

   2008-02-05T18:30:30 = 05/02/2008 18:30:30
   1995-12-22T09:05:02 = 22/12/1995 09:05:02
  -0010-09-15T04:44:23 = 15/09/-010 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 05/02/08 18:30
   1995-12-22T09:05:02 = 22/12/95 09:05
  -0010-09-15T04:44:23 = 15/09/-10 04:44

=head3 Default

   2008-02-05T18:30:30 = 05/02/2008 18:30:30
   1995-12-22T09:05:02 = 22/12/1995 09:05:02
  -0010-09-15T04:44:23 = 15/09/-010 04:44:23

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (EEE, d)

   2008-02-05T18:30:30 = ter, 5
   1995-12-22T09:05:02 = sex, 22
  -0010-09-15T04:44:23 = sáb, 15

=head3 HHmm (HH'h'mm)

   2008-02-05T18:30:30 = 18h30
   1995-12-22T09:05:02 = 09h05
  -0010-09-15T04:44:23 = 04h44

=head3 HHmmss (H'h'mm'min'ss's')

   2008-02-05T18:30:30 = 18h30min30s
   1995-12-22T09:05:02 = 9h05min02s
  -0010-09-15T04:44:23 = 4h44min23s

=head3 Hm (H'h'mm)

   2008-02-05T18:30:30 = 18h30
   1995-12-22T09:05:02 = 9h05
  -0010-09-15T04:44:23 = 4h44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 PM
   1995-12-22T09:05:02 = 9:05 AM
  -0010-09-15T04:44:23 = 4:44 AM

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 PM
   1995-12-22T09:05:02 = 9:05:02 AM
  -0010-09-15T04:44:23 = 4:44:23 AM

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d/M)

   2008-02-05T18:30:30 = 5/2
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/9

=head3 MEd (EEE, dd/MM)

   2008-02-05T18:30:30 = ter, 05/02
   1995-12-22T09:05:02 = sex, 22/12
  -0010-09-15T04:44:23 = sáb, 15/09

=head3 MMdd (dd/MM)

   2008-02-05T18:30:30 = 05/02
   1995-12-22T09:05:02 = 22/12
  -0010-09-15T04:44:23 = 15/09

=head3 MMM (LLL)

   2008-02-05T18:30:30 = fev
   1995-12-22T09:05:02 = dez
  -0010-09-15T04:44:23 = set

=head3 MMMd (d 'de' MMM)

   2008-02-05T18:30:30 = 5 de fev
   1995-12-22T09:05:02 = 22 de dez
  -0010-09-15T04:44:23 = 15 de set

=head3 MMMEd (EEE, d 'de' MMM)

   2008-02-05T18:30:30 = ter, 5 de fev
   1995-12-22T09:05:02 = sex, 22 de dez
  -0010-09-15T04:44:23 = sáb, 15 de set

=head3 MMMMd (d 'de' MMMM)

   2008-02-05T18:30:30 = 5 de fevereiro
   1995-12-22T09:05:02 = 22 de dezembro
  -0010-09-15T04:44:23 = 15 de setembro

=head3 MMMMEd (EEE, d 'de' MMMM)

   2008-02-05T18:30:30 = ter, 5 de fevereiro
   1995-12-22T09:05:02 = sex, 22 de dezembro
  -0010-09-15T04:44:23 = sáb, 15 de setembro

=head3 mmss (mm'min'ss's')

   2008-02-05T18:30:30 = 30min30s
   1995-12-22T09:05:02 = 05min02s
  -0010-09-15T04:44:23 = 44min23s

=head3 ms (mm'min'ss's')

   2008-02-05T18:30:30 = 30min30s
   1995-12-22T09:05:02 = 05min02s
  -0010-09-15T04:44:23 = 44min23s

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (MM/yyyy)

   2008-02-05T18:30:30 = 02/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 09/-010

=head3 yMEd (EEE, dd/MM/yyyy)

   2008-02-05T18:30:30 = ter, 05/02/2008
   1995-12-22T09:05:02 = sex, 22/12/1995
  -0010-09-15T04:44:23 = sáb, 15/09/-010

=head3 yMMM (MMM 'de' y)

   2008-02-05T18:30:30 = fev de 2008
   1995-12-22T09:05:02 = dez de 1995
  -0010-09-15T04:44:23 = set de -10

=head3 yMMMEd (EEE, d 'de' MMM 'de' y)

   2008-02-05T18:30:30 = ter, 5 de fev de 2008
   1995-12-22T09:05:02 = sex, 22 de dez de 1995
  -0010-09-15T04:44:23 = sáb, 15 de set de -10

=head3 yMMMM (MMMM 'de' y)

   2008-02-05T18:30:30 = fevereiro de 2008
   1995-12-22T09:05:02 = dezembro de 1995
  -0010-09-15T04:44:23 = setembro de -10

=head3 yQ (yyyy Q)

   2008-02-05T18:30:30 = 2008 1
   1995-12-22T09:05:02 = 1995 4
  -0010-09-15T04:44:23 = -010 3

=head3 yQQQ (y QQQ)

   2008-02-05T18:30:30 = 2008 T1
   1995-12-22T09:05:02 = 1995 T4
  -0010-09-15T04:44:23 = -10 T3

=head3 yyMM (MM/yy)

   2008-02-05T18:30:30 = 02/08
   1995-12-22T09:05:02 = 12/95
  -0010-09-15T04:44:23 = 09/-10

=head3 yyMMM (MMM 'de' yy)

   2008-02-05T18:30:30 = fev de 08
   1995-12-22T09:05:02 = dez de 95
  -0010-09-15T04:44:23 = set de -10

=head3 yyMMMd (d 'de' MMM 'de' yy)

   2008-02-05T18:30:30 = 5 de fev de 08
   1995-12-22T09:05:02 = 22 de dez de 95
  -0010-09-15T04:44:23 = 15 de set de -10

=head3 yyMMMEEEd (EEE, d 'de' MMM 'de' yy)

   2008-02-05T18:30:30 = ter, 5 de fev de 08
   1995-12-22T09:05:02 = sex, 22 de dez de 95
  -0010-09-15T04:44:23 = sáb, 15 de set de -10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyyMM (MM/yyyy)

   2008-02-05T18:30:30 = 02/2008
   1995-12-22T09:05:02 = 12/1995
  -0010-09-15T04:44:23 = 09/-010

=head3 yyyyMMM (MMM 'de' y)

   2008-02-05T18:30:30 = fev de 2008
   1995-12-22T09:05:02 = dez de 1995
  -0010-09-15T04:44:23 = set de -10

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

segunda-feira


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
