###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file vi.xml
# The source file version number was 1.86, generated on
# 2009/06/15 20:34:50.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::vi;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::root';

sub cldr_version { return "1\.7\.1" }

{
    my $am_pm_abbreviated = [ "SA", "CH" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ \'ngày\'\ dd\ MMMM\ \'năm\'\ y";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "\'Ngày\'\ dd\ \'tháng\'\ M\ \'năm\'\ y";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "dd\-MM\-yyyy";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "dd\/MM\/yyyy";
    sub date_format_short { return $date_format_short }
}

{
    my $datetime_format = "\{0\}\ \{1\}";
    sub datetime_format { return $datetime_format }
}

{
    my $day_format_abbreviated = [ "Th\ 2", "Th\ 3", "Th\ 4", "Th\ 5", "Th\ 6", "Th\ 7", "CN" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_format_abbreviated() }

{
    my $day_format_wide = [ "Thứ\ hai", "Thứ\ ba", "Thứ\ tư", "Thứ\ năm", "Thứ\ sáu", "Thứ\ bảy", "Chủ\ nhật" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }


sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "tr\.\ CN", "sau\ CN" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $first_day_of_week = "1";
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "thg\ 1", "thg\ 2", "thg\ 3", "thg\ 4", "thg\ 5", "thg\ 6", "thg\ 7", "thg\ 8", "thg\ 9", "thg\ 10", "thg\ 11", "thg\ 12" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_format_abbreviated() }

{
    my $month_format_wide = [ "tháng\ một", "tháng\ hai", "tháng\ ba", "tháng\ tư", "tháng\ năm", "tháng\ sáu", "tháng\ bảy", "tháng\ tám", "tháng\ chín", "tháng\ mười", "tháng\ mười\ một", "tháng\ mười\ hai" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }


sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $time_format_full = "HH\:mm\:ss\ zzzz";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_H = "H";
    sub _format_for_H { return $_format_for_H }
}

{
    my $_format_for_HHmm = "HH\:mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\:mm\:ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_MEd = "E\,\ d\-M";
    sub _format_for_MEd { return $_format_for_MEd }
}

{
    my $_format_for_MMMEd = "E\ d\ MMM";
    sub _format_for_MMMEd { return $_format_for_MMMEd }
}

{
    my $_format_for_MMMMEd = "E\ d\ MMMM";
    sub _format_for_MMMMEd { return $_format_for_MMMMEd }
}

{
    my $_format_for_MMMMd = "d\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_MMMd = "d\ MMM";
    sub _format_for_MMMd { return $_format_for_MMMd }
}

{
    my $_format_for_MMdd = "dd\-MM";
    sub _format_for_MMdd { return $_format_for_MMdd }
}

{
    my $_format_for_Md = "d\-M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_mmss = "mm\:ss";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_yMEd = "EEE\,\ d\-M\-yyyy";
    sub _format_for_yMEd { return $_format_for_yMEd }
}

{
    my $_format_for_yMMM = "MMM\ y";
    sub _format_for_yMMM { return $_format_for_yMMM }
}

{
    my $_format_for_yMMMEd = "EEE\,\ d\ MMM\ y";
    sub _format_for_yMMMEd { return $_format_for_yMMMEd }
}

{
    my $_format_for_yMMMM = "MMMM\ y";
    sub _format_for_yMMMM { return $_format_for_yMMMM }
}

{
    my $_format_for_yQ = "Q\ yyyy";
    sub _format_for_yQ { return $_format_for_yQ }
}

{
    my $_format_for_yQQQ = "QQQ\ y";
    sub _format_for_yQQQ { return $_format_for_yQQQ }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyy = "y";
    sub _format_for_yyyy { return $_format_for_yyyy }
}

{
    my $_format_for_yyyyMM = "MM\-yyyy";
    sub _format_for_yyyyMM { return $_format_for_yyyyMM }
}

{
    my $_available_formats =
        {
          "H" => "H",
          "HHmm" => "HH\:mm",
          "HHmmss" => "HH\:mm\:ss",
          "MEd" => "E\,\ d\-M",
          "MMMEd" => "E\ d\ MMM",
          "MMMMEd" => "E\ d\ MMMM",
          "MMMMd" => "d\ MMMM",
          "MMMd" => "d\ MMM",
          "MMdd" => "dd\-MM",
          "Md" => "d\-M",
          "mmss" => "mm\:ss",
          "yMEd" => "EEE\,\ d\-M\-yyyy",
          "yMMM" => "MMM\ y",
          "yMMMEd" => "EEE\,\ d\ MMM\ y",
          "yMMMM" => "MMMM\ y",
          "yQ" => "Q\ yyyy",
          "yQQQ" => "QQQ\ y",
          "yyQ" => "Q\ yy",
          "yyyy" => "y",
          "yyyyMM" => "MM\-yyyy"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::vi

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'vi' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Vietnamese.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Thứ hai
  Thứ ba
  Thứ tư
  Thứ năm
  Thứ sáu
  Thứ bảy
  Chủ nhật

=head3 Abbreviated (format)

  Th 2
  Th 3
  Th 4
  Th 5
  Th 6
  Th 7
  CN

=head3 Narrow (format)

  Th 2
  Th 3
  Th 4
  Th 5
  Th 6
  Th 7
  CN

=head3 Wide (stand-alone)

  Thứ hai
  Thứ ba
  Thứ tư
  Thứ năm
  Thứ sáu
  Thứ bảy
  Chủ nhật

=head3 Abbreviated (stand-alone)

  Th 2
  Th 3
  Th 4
  Th 5
  Th 6
  Th 7
  CN

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  tháng một
  tháng hai
  tháng ba
  tháng tư
  tháng năm
  tháng sáu
  tháng bảy
  tháng tám
  tháng chín
  tháng mười
  tháng mười một
  tháng mười hai

=head3 Abbreviated (format)

  thg 1
  thg 2
  thg 3
  thg 4
  thg 5
  thg 6
  thg 7
  thg 8
  thg 9
  thg 10
  thg 11
  thg 12

=head3 Narrow (format)

  thg 1
  thg 2
  thg 3
  thg 4
  thg 5
  thg 6
  thg 7
  thg 8
  thg 9
  thg 10
  thg 11
  thg 12

=head3 Wide (stand-alone)

  tháng một
  tháng hai
  tháng ba
  tháng tư
  tháng năm
  tháng sáu
  tháng bảy
  tháng tám
  tháng chín
  tháng mười
  tháng mười một
  tháng mười hai

=head3 Abbreviated (stand-alone)

  thg 1
  thg 2
  thg 3
  thg 4
  thg 5
  thg 6
  thg 7
  thg 8
  thg 9
  thg 10
  thg 11
  thg 12

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  tr. CN
  sau CN

=head3 Narrow

  tr. CN
  sau CN

=head2 Date Formats

=head3 Full

   2008-02-05T18:30:30 = Thứ ba, ngày 05 tháng hai năm 2008
   1995-12-22T09:05:02 = Thứ sáu, ngày 22 tháng mười hai năm 1995
  -0010-09-15T04:44:23 = Thứ bảy, ngày 15 tháng chín năm -10

=head3 Long

   2008-02-05T18:30:30 = Ngày 05 tháng 2 năm 2008
   1995-12-22T09:05:02 = Ngày 22 tháng 12 năm 1995
  -0010-09-15T04:44:23 = Ngày 15 tháng 9 năm -10

=head3 Medium

   2008-02-05T18:30:30 = 05-02-2008
   1995-12-22T09:05:02 = 22-12-1995
  -0010-09-15T04:44:23 = 15-09--010

=head3 Short

   2008-02-05T18:30:30 = 05/02/2008
   1995-12-22T09:05:02 = 22/12/1995
  -0010-09-15T04:44:23 = 15/09/-010

=head3 Default

   2008-02-05T18:30:30 = 05-02-2008
   1995-12-22T09:05:02 = 22-12-1995
  -0010-09-15T04:44:23 = 15-09--010

=head2 Time Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-09-15T04:44:23 = 04:44:23 UTC

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Short

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 Default

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head2 Datetime Formats

=head3 Full

   2008-02-05T18:30:30 = 18:30:30 UTC Thứ ba, ngày 05 tháng hai năm 2008
   1995-12-22T09:05:02 = 09:05:02 UTC Thứ sáu, ngày 22 tháng mười hai năm 1995
  -0010-09-15T04:44:23 = 04:44:23 UTC Thứ bảy, ngày 15 tháng chín năm -10

=head3 Long

   2008-02-05T18:30:30 = 18:30:30 UTC Ngày 05 tháng 2 năm 2008
   1995-12-22T09:05:02 = 09:05:02 UTC Ngày 22 tháng 12 năm 1995
  -0010-09-15T04:44:23 = 04:44:23 UTC Ngày 15 tháng 9 năm -10

=head3 Medium

   2008-02-05T18:30:30 = 18:30:30 05-02-2008
   1995-12-22T09:05:02 = 09:05:02 22-12-1995
  -0010-09-15T04:44:23 = 04:44:23 15-09--010

=head3 Short

   2008-02-05T18:30:30 = 18:30 05/02/2008
   1995-12-22T09:05:02 = 09:05 22/12/1995
  -0010-09-15T04:44:23 = 04:44 15/09/-010

=head3 Default

   2008-02-05T18:30:30 = 18:30:30 05-02-2008
   1995-12-22T09:05:02 = 09:05:02 22-12-1995
  -0010-09-15T04:44:23 = 04:44:23 15-09--010

=head2 Available Formats

=head3 d (d)

   2008-02-05T18:30:30 = 5
   1995-12-22T09:05:02 = 22
  -0010-09-15T04:44:23 = 15

=head3 EEEd (d EEE)

   2008-02-05T18:30:30 = 5 Th 3
   1995-12-22T09:05:02 = 22 Th 6
  -0010-09-15T04:44:23 = 15 Th 7

=head3 H (H)

   2008-02-05T18:30:30 = 18
   1995-12-22T09:05:02 = 9
  -0010-09-15T04:44:23 = 4

=head3 HHmm (HH:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 09:05
  -0010-09-15T04:44:23 = 04:44

=head3 HHmmss (HH:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-09-15T04:44:23 = 04:44:23

=head3 Hm (H:mm)

   2008-02-05T18:30:30 = 18:30
   1995-12-22T09:05:02 = 9:05
  -0010-09-15T04:44:23 = 4:44

=head3 hm (h:mm a)

   2008-02-05T18:30:30 = 6:30 CH
   1995-12-22T09:05:02 = 9:05 SA
  -0010-09-15T04:44:23 = 4:44 SA

=head3 Hms (H:mm:ss)

   2008-02-05T18:30:30 = 18:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-09-15T04:44:23 = 4:44:23

=head3 hms (h:mm:ss a)

   2008-02-05T18:30:30 = 6:30:30 CH
   1995-12-22T09:05:02 = 9:05:02 SA
  -0010-09-15T04:44:23 = 4:44:23 SA

=head3 M (L)

   2008-02-05T18:30:30 = 2
   1995-12-22T09:05:02 = 12
  -0010-09-15T04:44:23 = 9

=head3 Md (d-M)

   2008-02-05T18:30:30 = 5-2
   1995-12-22T09:05:02 = 22-12
  -0010-09-15T04:44:23 = 15-9

=head3 MEd (E, d-M)

   2008-02-05T18:30:30 = Th 3, 5-2
   1995-12-22T09:05:02 = Th 6, 22-12
  -0010-09-15T04:44:23 = Th 7, 15-9

=head3 MMdd (dd-MM)

   2008-02-05T18:30:30 = 05-02
   1995-12-22T09:05:02 = 22-12
  -0010-09-15T04:44:23 = 15-09

=head3 MMM (LLL)

   2008-02-05T18:30:30 = thg 2
   1995-12-22T09:05:02 = thg 12
  -0010-09-15T04:44:23 = thg 9

=head3 MMMd (d MMM)

   2008-02-05T18:30:30 = 5 thg 2
   1995-12-22T09:05:02 = 22 thg 12
  -0010-09-15T04:44:23 = 15 thg 9

=head3 MMMEd (E d MMM)

   2008-02-05T18:30:30 = Th 3 5 thg 2
   1995-12-22T09:05:02 = Th 6 22 thg 12
  -0010-09-15T04:44:23 = Th 7 15 thg 9

=head3 MMMMd (d MMMM)

   2008-02-05T18:30:30 = 5 tháng hai
   1995-12-22T09:05:02 = 22 tháng mười hai
  -0010-09-15T04:44:23 = 15 tháng chín

=head3 MMMMEd (E d MMMM)

   2008-02-05T18:30:30 = Th 3 5 tháng hai
   1995-12-22T09:05:02 = Th 6 22 tháng mười hai
  -0010-09-15T04:44:23 = Th 7 15 tháng chín

=head3 mmss (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 ms (mm:ss)

   2008-02-05T18:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-09-15T04:44:23 = 44:23

=head3 y (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yM (y-M)

   2008-02-05T18:30:30 = 2008-2
   1995-12-22T09:05:02 = 1995-12
  -0010-09-15T04:44:23 = -10-9

=head3 yMEd (EEE, d-M-yyyy)

   2008-02-05T18:30:30 = Th 3, 5-2-2008
   1995-12-22T09:05:02 = Th 6, 22-12-1995
  -0010-09-15T04:44:23 = Th 7, 15-9--010

=head3 yMMM (MMM y)

   2008-02-05T18:30:30 = thg 2 2008
   1995-12-22T09:05:02 = thg 12 1995
  -0010-09-15T04:44:23 = thg 9 -10

=head3 yMMMEd (EEE, d MMM y)

   2008-02-05T18:30:30 = Th 3, 5 thg 2 2008
   1995-12-22T09:05:02 = Th 6, 22 thg 12 1995
  -0010-09-15T04:44:23 = Th 7, 15 thg 9 -10

=head3 yMMMM (MMMM y)

   2008-02-05T18:30:30 = tháng hai 2008
   1995-12-22T09:05:02 = tháng mười hai 1995
  -0010-09-15T04:44:23 = tháng chín -10

=head3 yQ (Q yyyy)

   2008-02-05T18:30:30 = 1 2008
   1995-12-22T09:05:02 = 4 1995
  -0010-09-15T04:44:23 = 3 -010

=head3 yQQQ (QQQ y)

   2008-02-05T18:30:30 = Q1 2008
   1995-12-22T09:05:02 = Q4 1995
  -0010-09-15T04:44:23 = Q3 -10

=head3 yyQ (Q yy)

   2008-02-05T18:30:30 = 1 08
   1995-12-22T09:05:02 = 4 95
  -0010-09-15T04:44:23 = 3 -10

=head3 yyyy (y)

   2008-02-05T18:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-09-15T04:44:23 = -10

=head3 yyyyMM (MM-yyyy)

   2008-02-05T18:30:30 = 02-2008
   1995-12-22T09:05:02 = 12-1995
  -0010-09-15T04:44:23 = 09--010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Thứ hai


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
